@@ -128,6 +128,10 @@ class command:
     INSERTTEXT = index; index += 1
     IVALID = index; index += 1
     INVOKEMENU = index; index += 1
+    ISCHILDINDEXSELECTED = index; index += 1
+    ISCHILDITEMINDEXSELECTED = index; index += 1
+    ISCHILDITEMSELECTED = index; index += 1
+    ISCHILDSELECTED = index; index += 1
     ISTEXTSTATEENABLED = index; index += 1
     KBDENTER = index; index += 1
     KEYPRESS = index; index += 1
@@ -158,7 +162,9 @@ class command:
     SCROLLLEFT = index; index += 1
     SCROLLRIGHT = index; index += 1
     SCROLLUP = index; index += 1
+    SELECTALL = index; index += 1
     SELECTCALENDARDATE = index; index += 1
+    SELECTEDITEMCOUNT = index; index += 1
     SELECTEVENT = index; index += 1
     SELECTEVENTINDEX = index; index += 1
     SELECTINDEX = index; index += 1
@@ -197,6 +203,10 @@ class command:
     TITLEBARSELECTMENUITEM = index; index += 1
     UNCHECK = index; index += 1
     UNCHECKROW = index; index += 1
+    UNSELECTALL = index; index += 1
+    UNSELECTINDEX = index; index += 1
+    UNSELECTITEM = index; index += 1
+    UNSELECTITEMINDEX = index; index += 1
     VERIFYBUTTONCOUNT = index; index += 1
     VERIFYCHECK = index; index += 1
     VERIFYCHECKROW = index; index += 1
@@ -208,6 +218,8 @@ class command:
     VERIFYPARTIALMATCH = index; index += 1
     VERIFYPARTIALTABLECELL = index; index += 1
     VERIFYPUSHBUTTON = index; index += 1
+    VERIFYPROGRESSBAR = index; index += 1
+    VERIFYPROGRESSBARVISIBLE = index; index += 1
     VERIFYSCROLLBAR = index; index += 1
     VERIFYSCROLLBARHORIZONTAL = index; index += 1
     VERIFYSCROLLBARVERTICAL = index; index += 1
@@ -228,8 +240,52 @@ class command:
     VERIFYVISIBLEBUTTONCOUNT = index; index += 1
     WAITTILLGUIEXIST = index; index += 1
     WAITTILLGUINOTEXIST = index; index += 1
+    WINDOWUPTIME = index; index += 1
 
 class state:
+    """
+    INVALID - Accessibility.STATE_INVALID
+    ACTIVE - Accessibility.STATE_ACTIVE
+    ARMED = Accessibility.STATE_ARMED
+    BUSY = Accessibility.STATE_BUSY
+    CHECKED = Accessibility.STATE_CHECKED
+    COLLAPSED = Accessibility.STATE_COLLAPSED
+    DEFUNCT = Accessibility.STATE_DEFUNCT
+    EDITABLE = Accessibility.STATE_EDITABLE
+    ENABLED = Accessibility.STATE_ENABLED
+    EXPANDABLE = Accessibility.STATE_EXPANDABLE
+    EXPANDED = Accessibility.STATE_EXPANDED
+    FOCUSABLE = Accessibility.STATE_FOCUSABLE
+    FOCUSED = Accessibility.STATE_FOCUSED
+    HAS_TOOLTIP = Accessibility.STATE_HAS_TOOLTIP
+    HORIZONTAL - Accessibility.STATE_HORIZONTAL
+    ICONIFIED - Accessibility.STATE_ICONIFIED
+    MODAL - Accessibility.STATE_MODAL
+    MULTI_LINE - Accessibility.STATE_MULTI_LINE
+    MULTISELECTABLE - Accessibility.STATE_MULTISELECTABLE
+    OPAQUE - Accessibility.STATE_OPAQUE
+    PRESSED - Accessibility.STATE_PRESSED
+    RESIZABLE - Accessibility.STATE_RESIZABLE
+    SELECTABLE - Accessibility.STATE_SELECTABLE
+    SELECTED - Accessibility.STATE_SELECTED
+    SENSITIVE - Accessibility.STATE_SENSITIVE
+    SHOWING - Accessibility.STATE_SHOWING
+    SINGLE_LINE - Accessibility.STATE_SINGLE_LINE
+    STALE - Accessibility.STATE_STALE
+    TRANSIENT - Accessibility.STATE_TRANSIENT
+    VERTICAL - Accessibility.STATE_VERTICAL
+    VISIBLE - Accessibility.STATE_VISIBLE
+    MANAGES_DESCENDANTS - Accessibility.STATE_MANAGES_DESCENDANTS
+    INDETERMINATE - Accessibility.STATE_INDETERMINATE
+    LAST_DEFINED - Accessibility.STATE_LAST_DEFINED
+    TRUNCATED - Accessibility.STATE_TRUNCATED
+    REQUIRED - Accessibility.STATE_REQUIRED
+    INVALID_ENTRY - Accessibility.STATE_INVALID_ENTRY
+    SUPPORTS_AUTOCOMPLETION - Accessibility.STATE_SUPPORTS_AUTOCOMPLETION
+    SELECTABLE_TEXT - Accessibility.STATE_SELECTABLE_TEXT
+    IS_DEFAULT - Accessibility.STATE_IS_DEFAULT
+    VISISTED - Accessibility.STATE_VISITED
+    """
     INVALID = Accessibility.STATE_INVALID
     ACTIVE = Accessibility.STATE_ACTIVE
     ARMED = Accessibility.STATE_ARMED
@@ -282,7 +338,7 @@ class state:
         IS_DEFAULT = Accessibility.STATE_IS_DEFAULT + __addValue
         VISISTED = Accessibility.STATE_VISITED + __addValue
     except:
-        if _ldtpDebug is not None:
+        if _ldtpDebug:
             print 'New roles'
         pass
 
@@ -474,8 +530,17 @@ class LdtpErrorCode:
     COMMAND_FAILED = [-1184, "Command failed"]
     UNABLE_TO_SET_SLIDER_VALUE = [-1185, "Unable to set slider value"]
     COMMAND_NOT_SUPPORTED = [-1186, "Command not supported on this platform"]
-    UNABLE_TO_GET_OBJECT_STATE = [-1187, "Unable to get all object states"]
-    SET_APP_UNDER_TEST_NAME_FAILED = [-1188, "Setting application name under test failed"]
+    UNABLE_TO_GET_OBJECT_STATE = [-1187,
+                                   "Unable to get all object states"]
+    SET_APP_UNDER_TEST_NAME_FAILED = [-1188,
+                                       "Setting application name under test failed"]
+    UNABLE_TO_DESELECT_LAYERED_PANE_ITEM = [-1189,
+                                             "Unable to deselect layared pane item"]
+    CHILD_NOT_SELECTED = [-1190, "Child not selected"]
+    UNABLE_TO_GET_SELECTED_ITEM_COUNT = [-1191,
+                                          "Unable to get selected item count"]
+    MOUSE_ACTION_FAILED = [-1192, "Mouse action failed"]
+    PROGRESSBAR_NOT_VISIBLE = [-1193, "Progress bar not visible"]
 
 class ExtendedRole:
     CALENDAR_VIEW = 1001 # Extended role, so using custom value
@@ -530,11 +595,17 @@ def connect2LdtpExecutionEngine ():
     if _display == None:
         raise LdtpExecutionError ('Missing DISPLAY environment variable. Running in text mode ?')    
 
+    _userName = 'LDTP'
+    if os.getenv ('USER'):
+        _userName = os.getenv ('USER')
+    elif os.getenv ('LOGNAME'):
+        _userName = os.getenv ('LOGNAME')
+
     if _ldtpDebug:
-        commands.getstatusoutput ('mkdir -p /tmp/ldtp-$USER')
+        commands.getstatusoutput ('mkdir -p /tmp/ldtp-%s' % _userName)
 
     _mainSock = None
-    _socketPath = '/tmp/ldtp-' + os.getenv ('USER') + '-' + _display
+    _socketPath = '/tmp/ldtp-%s-%s' % (_userName, _display)
     
     _ldtpUseTcp = False
     _ldtpServerAddr = None
@@ -621,21 +692,12 @@ def timeElapsed (prevTime):
     currTime = int (time.time () - prevTime)
     return currTime
 
-timedelay = os.getenv ('LDTP_DELAY_CMD')
 # Send given packet to server
 def sendpacket (msg, clientFd = None, recorder = False):
     flag = False
     try:
         try:
             _sendLck.acquire ()
-            if timedelay != None:
-                try:
-                    # Delay each command by 'timedelay' seconds
-                    time.sleep (int (timedelay))
-                except IndexError:
-                    # Default to 5 seconds delay if LDTP_DELAY_CMD
-                    # env variable is set
-                    time.sleep (5)
             flag = True
             if clientFd is None:
                 # Get client socket fd based on thread id
@@ -1100,6 +1162,8 @@ def getErrorMessage (errorCode, args):
         msg = "Toggle button state not enabled"
     elif errorCode == LdtpErrorCode.UNABLE_TO_GET_WINDOW_LIST:
         msg = "Unable to get window list"
+    elif errorCode == LdtpErrorCode.PROGRESSBAR_NOT_VISIBLE:
+        msg = "Progress bar not visible"
     else:
         msg = "Error code not found"
     return msg
