@@ -1,10 +1,9 @@
-#!/usr/bin/env python 
 #############################################################################
 #
 #  Linux Desktop Testing Project http://ldtp.freedesktop.org
 # 
 #  Author:
-#      Nagappan A (nagappan@gmail.com)   
+#      Nagappan Alagappan (nagappan@gmail.com)   
 # 
 #  Copyright 2004 - 2007 Novell, Inc.
 # 
@@ -53,16 +52,15 @@ contextList = []
 # Let us not register our application under at-spi application list
 os.environ ['GTK_MODULES'] = ''
 
-from ldtplib.ldtplibutils import *
+from ldtplibutils import *
 
 _ldtpDebug = os.getenv ('LDTP_DEBUG')
+_sockFdPool = sockFdPool
+_socketPath = '/tmp/ldtp-record-' + os.getenv ('USER') + '-' + os.getenv ('DISPLAY')
 
-class command:
-    INVALID       = 0
-    STOP          = 1
-    WINDOWEXIST   = 2
-    GETWINDOWNAME = 3
-    GETOBJECTNAME = 4
+
+# Default GUI timeout 30 seconds
+_ldtpGuiTimeout = 30
 
 class ConnectionLost (Exception):
     def __init__(self, value):
@@ -87,120 +85,67 @@ def generatexml (commandId, _requestId, name = None, application = None, argumen
     _xml += '</REQUEST>'
     return _xml
 
-# Send given packet to server
-def sendpacket (msg):
-    global _mainSock
-    flag = False
-    try:
-        try:
-            timedelay = os.getenv ('LDTP_DELAY_CMD')
-            _sendLck.acquire ()
-            if timedelay != None:
-                try:
-                    # Delay each command by 'timedelay' seconds
-                    time.sleep (int (timedelay))
-                except IndexError:
-                    # Default to 5 seconds delay if LDTP_DELAY_CMD
-                    # env variable is set
-                    time.sleep (5)
-            flag = True
-            
-            # Encode the message in UTF-8 so we don't break on extended
-            # characters in the application GUIs
-            try:
-                buf = msg.encode ('utf-8')
-            except UnicodeDecodeError:
-                buf = unicode (msg, 'utf-8').encode ('utf-8')
-    
-            if _mainSock == None:
-                _sendLck.release ()
-                return
-            # Pack length (integer value) in network byte order
-            msglen = struct.pack ('!i', len (buf))
-            # Send message length
-            _mainSock.send (msglen)
-    
-            # Send message
-            _mainSock.send (buf)
-            if _ldtpDebug != None and _ldtpDebug == '2':
-                print 'Send packet', buf
-            #_sendLck.release ()
-        except socket.error, msg:
-            raise LdtpExecutionError ('Server aborted')
-        except:
-            if _ldtpDebug:
-                if hasattr (traceback, 'format_exc'):
-                    if ldtpDebug:
-                        print traceback.format_exc ()
-                    raise LdtpExecutionError (str (traceback.format_exc ()))
-                else:
-                    if ldtpDebug:
-                        print traceback.print_exc ()
-                    raise LdtpExecutionError (str (traceback.print_exc ()))
-    finally:
-        if flag:
-            # Reason for using the flag:
-            # 'Do not call this method when the lock is unlocked.'
-            _sendLck.release ()
-            flag = False
+def connect2LdtpCodegen ():
+    _display = os.getenv ('DISPLAY')
+
+    if _display == None:
+        raise LdtpExecutionError ('Missing DISPLAY environment variable. Running in text mode ?')    
+
+    _sockFd = None    
+    _ldtpUseTcp = False
+    _ldtpServerAddr = None
+    _ldtpServerPort = None
+    if os.environ.has_key("LDTP_SERVER_ADDR"):
+        _ldtpServerAddr = os.environ ["LDTP_SERVER_ADDR"]
+        if os.environ.has_key ("LDTP_SERVER_PORT"):
+            _ldtpServerPort = int (os.environ ["LDTP_SERVER_PORT"])
+        else:
+            _ldtpServerPort = 23457
+        _ldtpUseTcp = True
 
-def recvpacket (peek_flag = 0):
-    global _mainSock
-    flag = False
     try:
-        try:
-            _recvLck.acquire ()
-            flag = True
-            _responsePacket = None
-            _mainSock.settimeout (5.0)
-            # Hardcoded 4 bytes, as the server sends 4 bytes as packet length
-            data = _mainSock.recv (4, peek_flag)
-            if data == '' or data == None:
-                if flag == True:
-                    # Reason for using the flag:
-                    # 'Do not call this method when the lock is unlocked.'
-                    _recvLck.release ()
-                flag = False
-                return None
-            _packetSize, = struct.unpack ('!i', data)
-            if peek_flag == 0 and _ldtpDebug != None and _ldtpDebug == '2':
-                print 'Received packet size', _packetSize
-            # MSG_PEEK
-            # This flag causes the receive operation to return data from the beginning
-            # of the receive queue without removing that data from  the  queue.
-            # Thus, a subsequent receive call will return the same data.
+        # Create a client socket
+        _sockFd = None
+        if _ldtpUseTcp:
+            _sockFd = socket.socket (socket.AF_INET, socket.SOCK_STREAM)
+        else:
+            _sockFd = socket.socket (socket.AF_UNIX, socket.SOCK_STREAM)
+    except socket.error,msg:
+        if _ldtpUseTcp:
+            raise LdtpExecutionError ('Error while creating socket  ' + str (msg))
+        else:
+            raise LdtpExecutionError ('Error while creating UNIX socket  ' + str (msg))    
     
-            if peek_flag != 0:
-                # MSG_PEEK
-                _responsePacket = _mainSock.recv (4 + _packetSize, peek_flag)
-            else:
-                _responsePacket = _mainSock.recv (_packetSize, peek_flag)
-            if peek_flag != 0:
-                _pattern = re.compile ('\<\?xml')
-                _searchObj = re.search (_pattern, _responsePacket)
-                _finalPacket = _responsePacket[_searchObj.start () :]
-                _responsePacket = _finalPacket
-            #_recvLck.release ()
-            if peek_flag == 0 and _ldtpDebug != None and _ldtpDebug == '2':
-                print 'Received response Packet', _responsePacket
-            return _responsePacket
-        except struct.error, msg:
-            raise LdtpExecutionError ('Invalid packet length ' + str (msg))
-        except socket.timeout:
-            if _ldtpDebug != None and _ldtpDebug == '2':
-                print 'Timeout'
-            return ''
-        except:
-            if hasattr (traceback, 'format_exc'):
-                raise LdtpExecutionError ('Error while receiving packet ' + str (traceback.format_exc ()))
-            else:
-                raise LdtpExecutionError ('Error while receiving packet ' + str (traceback.print_exc ()))
-    finally:
-        if flag:
-            # Reason for using the flag:
-            # 'Do not call this method when the lock is unlocked.'
-            _recvLck.release ()
-            flag = False
+    # Let us retry connecting to the server for 3 times
+    _retryCount = 0
+
+    while True:
+        try:
+            try:
+                # Connect to server socket
+                if _ldtpUseTcp:
+                    _sockFd.connect((_ldtpServerAddr, _ldtpServerPort))
+                else:
+                    _sockFd.connect (_socketPath)
+                return _sockFd, _ldtpUseTcp
+            except TypeError:
+                raise ConnectionLost ('Environment LDTP_AUTH_SOCK variable not set')
+        except socket.error, msg:
+            if _retryCount == 3:
+                raise ConnectionLost ('Could not establish connection ' + str (msg))
+            _retryCount += 1
+            #If we are not trying to connect to a remote server then we can attempt to
+            #startup the ldtp server and then try to re-connect to it.
+            if not _ldtpUseTcp:
+                _pid = os.fork ()
+                if _pid == 0:
+                    try:
+                        os.execvpe ('ldtpcodegen', [''], os.environ)
+                    except OSError:
+                        raise LdtpExecutionError ('ldtp executable not in PATH')
+                else:
+                    # Let us wait for 1 second, let the server starts
+                    time.sleep (1)
 
 def getText (nodelist):
     rc = ""
@@ -356,192 +301,6 @@ def parsekeyboardxml (xmldata):
         raise LdtpExecutionError ('Parsing XML error: ' + str (msg))
     return _keyboardData
 
-#def getresponse (packetId):
-#    while True:
-#        _readFlag.wait ()
-#        _readFlag.clear ()
-#        _ldtpDebug = os.getenv ('LDTP_DEBUG')
-#        peekResponsePacket = peekresponse ()
-#        if peekResponsePacket == None or peekResponsePacket == '':
-#            if _ldtpDebug != None and _ldtpDebug == '2':
-#                print 'Peekresponse None'
-#            continue
-#        try:
-#            _responseType, _responseStatus, _responseData = parsexml (peekResponsePacket)
-#        except TypeError, msg:
-#            if _ldtpDebug != None and _ldtpDebug == '2':
-#                print 'TypeError', msg
-#            continue
-#        # For precautions, we are just checking, whether the packet is notification or not
-#        if _responseType == 'notification' or _responseType == 'keyboard' or _responseType == None:
-#            continue
-#        if _responseStatus [2] == packetId:
-#            if _responseStatus [0] != 0 and _ldtpDebug != None:
-#                print '*** ' + _responseStatus [1]
-#            packet = recvpacket ()
-#            # As we have already parsed the packet,
-#            # we are just returning the parsed packet
-#            return _responseStatus, _responseData
-
-class PollServer (threading.Thread):
-    def __init__ (self,  pckt):
-        self.pckt = pckt
-        threading.Thread.__init__ (self)
-        self._events = None
-    def run (self):
-        try:
-            self.start_polling_server ()
-        except:
-            try:
-                self.shutdown ()
-                if hasattr (traceback, 'format_exc'):
-                    print traceback.format_exc ()
-                else:
-                    print traceback.print_exc ()
-            except AttributeError:
-                pass
-            except:
-                pass
-    def start_polling_server (self):
-        self._serverDisconnected = False
-        global _serverPoll
-        _serverPoll = select.poll ()
-        _serverPoll.register (_mainSock, select.POLLIN)
-
-        while True:
-            try:
-                self._events = _serverPoll.poll ()
-            except socket.error, msg:
-                break
-            except:
-                _serverPoll.unregister (_mainSock)
-                sys.exit ()
-            try:
-                if self._events == None:
-                    break
-                for i in range (0, len (self._events)):
-                    if (self._events [i][1] & select.POLLIN or self._events [i][1] & select.POLLPRI):
-                        try:
-                            if self.handlePacket () == None:
-                                self._serverDisconnected = True
-                                break
-                        except LdtpExecutionError, msg:
-                            self._serverDisconnected = True
-                            # _readFlag.set ()
-                            break
-                        except:
-                            if hasattr (traceback, 'format_exc'):
-                                print traceback.format_exc ()
-                            else:
-                                print traceback.print_exc ()
-                    elif (self._events [i][1] & select.POLLNVAL):
-                        # Unregister newly created socket from polling once its completed
-                        _serverPoll.unregister (self._events [i][0])
-                    else:
-                        self._serverDisconnected = True
-                        break
-                if self._serverDisconnected == True:
-                    raise LdtpExecutionError ('Server disconnected')
-            # Checking this exception due to bug # 333090 comment # 6
-            except TypeError:
-                _serverPoll.unregister (_mainSock)
-                sys.exit ()
-    def handlePacket (self):
-        self._responsePacket = None
-        try:
-            self._responsePacket = recvpacket ()
-        except KeyboardInterrupt:
-            return None
-        self._responseType = None
-        self._responseStatus = None
-        self._responseData = None
-        try:
-            if self._responsePacket == None:
-                # When there is no data to read let us quit
-                return None
-            if self._responsePacket != '':
-                self._responseType, self._responseStatus, self._responseData = parsexml (self._responsePacket)
-                if self._responseType == None:
-                    return None
-            else:
-                _readFlag.set ()
-        except TypeError:
-            if _ldtpDebug:
-                if hasattr (traceback, 'format_exc'):
-                    print traceback.format_exc ()
-                else:
-                    print traceback.print_exc ()
-            return ''
-        except LdtpExecutionError, msg:
-            if _ldtpDebug:
-                if hasattr (traceback, 'format_exc'):
-                    print traceback.format_exc ()
-                else:
-                    print traceback.print_exc ()
-            #_readFlag.set ()
-            return ''
-        except KeyboardInterrupt:
-            return None
-        try:
-            if self._responseType == 'notification':
-                if _notificationFlag.isSet ():
-                    # Let us allow only one callback function to execute at any point of time
-                    _notificationFlag.wait ()
-                    _notificationFlag.clear ()
-                    _windowName, _objectName, _objectType, _eventType, \
-                             _timeElapsed, _key, _data, _detail1, \
-                             _detail2 = parsenotificationxml (self._responsePacket)
-                    #packet = recvpacket ()
-                    # As we have already parsed the packet,
-                    # we are just returning the parsed packet
-                    self.pckt.pushPacket (self._responseType, _windowName, _objectName, _objectType, _eventType, \
-                             _timeElapsed, _key, _data, _detail1, _detail2)
-                    _notificationFlag.set ()
-                else:
-                    # CPU goes high for some time, if this delay is not there
-                    # as the notification packet is still in the Queue, but the
-                    # new spanned thread takes some time to receive the notification packet
-                    # So this delay is required
-                    time.sleep (1)
-            elif self._responseType == 'keyboard':
-                if _keyboardFlag.isSet ():
-                    # Let us allow only one callback function to execute at any point of time
-                    _keyboardFlag.wait ()
-                    _keyboardFlag.clear ()
-                    _keyboardData = parsekeyboardxml (self._responsePacket)
-                    # As we have already parsed the packet,
-                    # we are just returning the parsed packet
-                    #packet = recvpacket ()
-                    self.pckt.pushPacket (self._responseType, data = _keyboardData)
-                    _keyboardFlag.set ()
-                else:
-                    # CPU goes high for some time, if this delay is not there
-                    # as the keyboard packet is still in the Queue, but the
-                    # new spanned thread takes some time to receive the keyboard packet
-                    # So this delay is required
-                    time.sleep (1)
-            else:
-                _readFlag.set ()
-        except KeyboardInterrupt:
-            return None
-        return ''
-    def getresponse (self, packetId):
-        while True:
-            _readFlag.wait ()
-            _readFlag.clear ()
-            if self._responseType != 'response':
-                continue
-            if self._responseStatus [2] == packetId:
-                if _ldtpDebug and self._responseStatus [0] != 0:
-                    print '*** ' + self._responseStatus [1]
-                #packet = recvpacket ()
-                # As we have already parsed the packet,
-                # we are just returning the parsed packet
-            return self._responseStatus, self._responseData
-
-    def shutdown (self):
-        _readFlag.set ()
-
 class packetInfo:
     def __init__ (self, packetType, windowName, objectName, objectType, eventType,
               timeElapsed, key = None, data = None, detail1 = None,
@@ -600,13 +359,73 @@ class packet:
                 _pcktInfo = self._packet [self._startPacketId]
         return _pcktInfo
 
+def getresponse (packetId = None, sockfd = None, timeOut = True):
+    global _ldtpGuiTimeout
+    count = 0
+    # Let us initialize with empty string, as we are going to check for None later
+    # returned by recvpacket later
+    _responsePacket = ''
+    while count < _ldtpGuiTimeout:
+        try:
+            _responsePacket = recvpacket (sockfd = sockfd)
+            break
+        except LdtpExecutionError, msg:
+            if msg.value == 'Timeout':
+                if timeOut is False:
+                    # don't timeout, so don't increase the count !
+                    continue
+                # If timeout, let us retry for _ldtpGuiTimeout times
+                count += 1
+                continue
+            raise
+    if _responsePacket == None:
+        return None, None
+    try:
+        _responseType, _responseStatus, _responseData = parsexml (_responsePacket)
+        if _responseType == 'response':
+            # If response type is response, then let us enforce checking packetId
+            if _responseStatus [2] == packetId:
+                return _responseStatus, _responseData
+            else:
+                if _ldtpDebug:
+                    print 'Invalid response packet', _responseStatus [2], packetId
+                return (-1, "Invalid response packet", packetId), (0, None)
+        else:
+            # If notification, then return directly, don't check
+            _windowName, _objectName, _objectType, _eventType, \
+                _timeElapsed, _key, _data, _detail1, \
+                _detail2 = parsenotificationxml (_responsePacket)
+            pckt.pushPacket (_responseType, _windowName, _objectName,
+                             _objectType, _eventType, _timeElapsed, _key,
+                             _data, _detail1, _detail2)
+            if _ldtpDebug:
+                print 'notification', _responseType, _responseStatus
+        return _responseType, _responseStatus
+    except TypeError, msg:
+        if _ldtpDebug:
+            if hasattr (traceback, 'format_exc'):
+                print traceback.format_exc ()
+            else:
+                print traceback.print_exc ()
+        if _ldtpDebug != None and _ldtpDebug == '2':
+            print 'TypeError', msg
+        return -1, "Invalid response packet"
+    except:
+        if _ldtpDebug:
+            if hasattr (traceback, 'format_exc'):
+                print traceback.format_exc ()
+            else:
+                print traceback.print_exc ()
+        return None, None
+
 def doesWindowExist (windowName):
     try:
-        global _pollThread
+        # global _pollThread
+        _clientFd, _ldtpUseTcp = connect2LdtpCodegen ()
         _requestId  = str (random.randint (0, sys.maxint))
-        _message = generatexml (command.WINDOWEXIST, _requestId, windowName)
-        sendpacket (_message)
-        _responseStatus, _responseData = _pollThread.getresponse (_requestId)
+        _message = generatexml (RecordCommand.WINDOWEXIST, _requestId, windowName)
+        sendpacket (_message, _clientFd, recorder = True)
+        _responseStatus, _responseData = getresponse (_requestId, _clientFd)
         if _responseStatus [0] == 0:
             return True
         else:
@@ -616,11 +435,12 @@ def doesWindowExist (windowName):
 
 def getObjectName (objName):
     try:
-        global _pollThread
+        # global _pollThread
+        _clientFd, _ldtpUseTcp = connect2LdtpCodegen ()
         _requestId  = str (random.randint (0, sys.maxint))
-        _message = generatexml (command.GETOBJECTNAME, _requestId, objName)
-        sendpacket (_message)
-        _responseStatus, _responseData = _pollThread.getresponse (_requestId)
+        _message = generatexml (RecordCommand.GETOBJECTNAME, _requestId, objName)
+        sendpacket (_message, _clientFd, recorder = True)
+        _responseStatus, _responseData = getresponse (_requestId, _clientFd)
         if _responseStatus [0] == 0:
             return _responseData
         else:
@@ -651,12 +471,14 @@ def getapps ():
     if os.path.exists (path):
 	appListPath = path
     else:
-	print "Home copy not available"
+        if _ldtpDebug:
+            print "Home copy not available"
 	path = "%s/appdata" % APPROOT
 	if os.path.exists (path):
             appListPath = path
         else:
-            print "Even root copy not available"
+            if _ldtpDebug:
+                print "Even root copy not available"
 	    return appList
     f = open (appListPath)
     for item in f:
@@ -715,6 +537,71 @@ def objectOrient (line):
     line = '%s%s.%s%s' % (line, context, parts[0], parts[1])
     return line
 
+# Class Prefs to manage user preferences
+class Prefs:
+    def __init__ (self):
+        self.prefList = []
+        self.prefDic = {}
+        self.APPHOME = APPHOME
+        self.APPROOT = APPROOT
+        self.hash = re.compile ('^#')
+        self.equalTo = re.compile ('\s*\=\s*')
+        self.nonWhiteSpace = re.compile ('\S')
+    
+    def loadPrefs (self):
+        path = "%s/editor.conf" % self.APPHOME
+        if os.path.exists (path):
+	    prefListPath = path
+        else:
+            if _ldtpDebug:
+                print "Home copy not available"
+	    path = "%s/editor.conf" % self.APPROOT
+	    if os.path.exists (path):
+                prefListPath = path
+            else:
+                if _ldtpDebug:
+                    print "Even root copy not available"
+	        return
+        f = open (prefListPath)
+        for item in f:
+            self.prefList.append (item.strip ())
+        f.close ()
+        self.makePrefDic ()
+        return self.prefDic
+
+    def makePrefDic (self):
+        for item in self.prefList:
+            if self.hash.match (item) == None and self.nonWhiteSpace.search (item) != None:
+                valList = self.equalTo.split (item)
+                if  valList [1] == 'True':
+                    self.prefDic [valList [0]] = True
+                else:
+                    self.prefDic [valList [0]] = False
+
+    def savePrefDic (self, dic):
+        self.prefDic = dic
+        for i in range (len (self.prefList)):
+            if self.hash.match (self.prefList[i]) == None and self.nonWhiteSpace.search (self.prefList[i]) != None:
+                valList = self.equalTo.split (self.prefList[i])
+                for param, value in self.prefDic.iteritems ():
+                    if param == valList[0]:
+                        if value == True:
+                            self.prefList[i] = "%s = True" % param
+                        else:
+                            self.prefList[i] = "%s = False" % param
+                        break
+        self.savePrefs()
+
+    def savePrefs (self):
+        path = "%s/editor.conf" % self.APPHOME
+        if os.path.exists (self.APPHOME) == False:
+            os.mkdir (self.APPHOME, 0755)
+        f = open (path, 'w')
+        for item in self.prefList:
+            item = "%s\n" % item
+            f.write (item)
+        f.close ()
+
 def callback (guiCallbackFunc, data, timeElapsed = None):
     global generatedCode
     if timeElapsed is not None:
@@ -1002,11 +889,12 @@ def processDataDebug (pckt, callbackFunc):
 
 def stoprecord (filename = None):
     try:
-        global _pollThread
+        # global _pollThread
+        _clientFd, _ldtpUseTcp = connect2LdtpCodegen ()
         _requestId  = str (random.randint (0, sys.maxint))
-        _message = generatexml (command.STOP, _requestId)
-        sendpacket (_message)
-        _responseStatus, _responseData = _pollThread.getresponse (_requestId)
+        _message = generatexml (RecordCommand.STOP, _requestId)
+        sendpacket (_message, _clientFd, recorder = True)
+        _responseStatus, _responseData = getresponse (_requestId, _clientFd)
     except:
         pass
 
@@ -1019,9 +907,10 @@ def shutdown ():
 
 def __shutdownAndExit (signum, frame):
     global generatedCode,  _mainSock
-    stoprecord ()
-    if _mainSock is not None:
+    if _mainSock:
         _mainSock.close ()
+        _mainSock = None
+        stoprecord ()
     shutdown ()
     if _ldtpDebug:
         print ''
@@ -1035,8 +924,6 @@ def __shutdownAndExit (signum, frame):
 def stop ():
     __shutdownAndExit (0, 0)
 
-_socketPath = '/tmp/ldtp-record-' + os.getenv ('USER') + '-' + os.getenv ('DISPLAY')
-
 # Create read flag
 _readFlag = threading.Event ()
 # Clear the flag by default
@@ -1053,7 +940,7 @@ _keyboardFlag = threading.Event ()
 _keyboardFlag.set ()
 
 # Contains poll fd's
-_serverPoll = None
+# _serverPoll = None
 
 # Send lock
 _sendLck = threading.Lock ()
@@ -1061,53 +948,75 @@ _sendLck = threading.Lock ()
 _recvLck = threading.Lock ()
 
 _mainSock = None
-_pollThread = None
+# _pollThread = None
 calledFromGui = False
 generatedCode = ''
+pckt = packet ()
+
+def invokecallback (_clientFd):
+    global _mainSock
+    _mainSock = _clientFd
+    try:
+        _requestId  = str (random.randint (0, sys.maxint))
+        _message = generatexml (RecordCommand.NOTIFICATION, _requestId)
+        sendpacket (_message, _clientFd, recorder = True)
+    except KeyboardInterrupt:
+        if _ldtpDebug:
+            print 'Keyboard interrupt'
+        return
+    except socket.error:
+        if _ldtpDebug:
+            print 'Socket error'
+        return
+    except:
+        if _ldtpDebug:
+            if hasattr (traceback, 'format_exc'):
+                print traceback.format_exc ()
+            else:
+                print traceback.print_exc ()
+
+    while True:
+        try:
+            _responseStatus, _responseData = getresponse (sockfd = _clientFd,
+                                                          timeOut = False)
+            if _responseStatus == None:
+                if _mainSock:
+                    _mainSock.close ()
+                    _mainSock = None
+                # Server closed connection
+                if _ldtpDebug:
+                    print 'Server closed connection'
+                break
+        except KeyboardInterrupt:
+            if _ldtpDebug:
+                print 'Keyboard interrupt'
+            break
+        except LdtpExecutionError, error:
+            if _ldtpDebug:
+                print 'Ldtp execution error %s' % str (error)
+            break
+        except socket.error:
+            if _ldtpDebug:
+                print 'Socket error'
+            break
+        except:
+            if _ldtpDebug:
+                if hasattr (traceback, 'format_exc'):
+                    print traceback.format_exc ()
+                else:
+                    print traceback.print_exc ()
+            break
 
 #All default parameters, and checking whether action is stoprecord, are to be removed
 def start (callbackFunc, appName = 'ALL', args = None):
     if callbackFunc == None or callable (callbackFunc) == False:
         raise LdtpExecutionError ('Callback function is not callable')
-    global _mainSock, _pollThread,  generatedCode
-    try:
-        # Create a client socket
-        _mainSock = socket.socket (socket.AF_UNIX, socket.SOCK_STREAM)
-    except socket.error,msg:
-        raise LdtpExecutionError ('Error while creating UNIX socket  ' + str (msg))
-
-    # Let us retry connecting to the server for 3 times
-    retryCount = 0
-
-    while True:
-        try:
-            try:
-                # Connect to server socket
-                _mainSock.connect (_socketPath)
-                break
-            except TypeError:
-                raise ConnectionLost ('Unable to establish connection with ldtp code generator')
-        except socket.error, msg:
-            if retryCount == 3:
-                raise ConnectionLost ('Could not establish connection ' + str (msg))
-            retryCount += 1
-            _pid = os.fork ()
-            if _pid == 0:
-                try:
-                    os.execvpe ('ldtpcodegen', [''], os.environ)
-                    os._exit (os.EX_OK)
-                except OSError:
-                    raise LdtpExecutionError ('ldtp executable not in PATH')
-            else:
-                # Let us wait for 1 second, let the server starts
-                time.sleep (1)
-
-    pckt = packet ()
+    global generatedCode
     generatedCode = 'from ldtp import *\n\n'
+    _clientFd, _ldtpUseTcp = connect2LdtpCodegen ()
 
-    # Start polling server
-    _pollThread = PollServer (pckt)
-    _pollThread.setDaemon (True)
-    _pollThread.start ()
+    _sockFdPool = sockFdPool
+    _sockFdPool [threading.currentThread ()] = _clientFd
 
+    thread.start_new_thread (invokecallback, (_clientFd, ))
     thread.start_new_thread (processData, (pckt, callbackFunc))
