@@ -26,7 +26,7 @@
 
 __author__ = "Nagappan Alagappan <nagappan@gmail.com>"
 # __maintainer__ = "Nagappan Alagappan <nagappan@gmail.com>"
-__version__ = "1.5.0"
+__version__ = "1.5.1"
 
 import ldtp
 
@@ -39,7 +39,7 @@ class component:
         self.role = role
 
         if name != '' and role == '':
-                self.role = ldtp.getobjectproperty (window, name, 'class')
+            self.role = ldtp.getobjectproperty (window, name, 'class')
         try:
             self.label = ldtp.getobjectproperty (window, self.getName (name), 'label_by')
         except ldtp.LdtpExecutionError:
@@ -58,6 +58,9 @@ class component:
                 return ''
             raise ldtp.LdtpExecutionError ('Object \'name\' argument required')
 
+    def getrole (self):
+        return self.role
+
     def getwindowsize (self):
         return ldtp.getwindowsize (self.__window)
 
@@ -73,8 +76,8 @@ class component:
     def guiexist (self):
         return ldtp.guiexist (self.__window)
 
-    def hasstate (self, name = '', checkState = state.INVALID):
-        return ldtp.hasstate (self.__window, self.getName (name), checkState)
+    def hasstate (self, name = '', *checkState):
+        return ldtp.hasstate (self.__window, self.getName (name), *checkState)
 
     def getobjectinfo (self, name = ''):
         return ldtp.getobjectinfo (self.__window, self.getName (name))
@@ -952,17 +955,11 @@ class component:
         else:
             raise ldtp.LdtpExecutionError ('Mismatch arguments')
 
-class context (component):
-    def __init__ (self, window) :
-        component.__init__ (self, window)
-        self.__window = window
-        # self.component = component (window)
-
     def getchild (self, name = '', role = ''):
         if name == '' and role == '':
             raise ldtp.LdtpExecutionError ('Atleast one argument should be provided <object name> or <role name>')
         if role != '':
-            childList = ldtp.getchild (self.__window, name, role)
+            childList = ldtp.getchild (self.__window, name, role, self.__name)
             componentList = []
             for i in childList:
                 componentList.append (component (self.__window, i, role))
@@ -970,6 +967,15 @@ class context (component):
         else:
             return component (self.__window, name)
 
+
+
+class context (component):
+    def __init__ (self, window) :
+        # name of component and window are the same
+        component.__init__ (self, window, window)
+        self.__window = window
+        # self.component = component (window)
+
     def onwindowcreate (self, cbFunction):
         return ldtp.onwindowcreate (self.__window, cbFunction)
 
