@@ -43,6 +43,7 @@ extern gint ldtp_gui_timeout;
 extern gint ldtp_obj_timeout;
 extern GHashTable *event_notifier;
 extern GHashTable *client_context;
+extern GHashTable *window_duration;
 extern gboolean ldtp_script_service;
 extern gboolean ldtp_external_xml_file;
 
@@ -366,17 +367,27 @@ is_role_matching (gpointer key, gpointer value, gpointer list)
 static void
 add_matching_item_to_list (gpointer key, gpointer value, gpointer list)
 {
-	MatchingList *list_item = list;
 	gchar *tmp   = NULL;
 	gchar *data  = NULL;
 	gchar *label = NULL;
 	gchar *tmp_label = NULL;
 	gchar *escaped_xml_data = NULL;
+	MatchingList *list_item = list;
+
         if (!key || !value || !list)
                 return;
+
 	data = list_item->data;
+
 	if (ldtp_debug && data)
 		g_print ("key: %s - %s\n", (gchar *) key, data);
+	if (list_item->children_ht &&
+	    g_hash_table_lookup_extended (list_item->children_ht,
+					  key, NULL, NULL) == FALSE) {
+		// If key doesn't exist in children_ht, then don't
+		// process further
+		return;
+	}
 	/*
 	  list_item->role == NULL ? then, let us add all of the entries to the list
 	*/
@@ -691,8 +702,6 @@ get_all_states (LDTPClientContext* cctxt,
 		LDTPErrorCode* err)
 {
 	guint i;
-	char *state = NULL;
-	long int state_id;
 	AccessibleStateSet *state_set;
 
 	state_set = Accessible_getStateSet (cctxt->gui_handle->handle);
@@ -753,6 +762,192 @@ get_all_states (LDTPClientContext* cctxt,
 	cctxt->gui_handle = NULL;
 }
 
+static void
+copy_hash_table (gpointer key, gpointer value, gpointer list)
+{
+	if (!key || !value || !list)
+		return;
+	g_hash_table_insert (list, g_strdup (key), g_strdup (value));
+}
+
+static void
+set_traversed (gpointer key, gpointer value, gpointer list)
+{
+	if (!key || !value || !list)
+		return;
+	if (g_hash_table_lookup_extended (list, key, NULL, NULL)) {
+		g_hash_table_replace (list, g_strdup (key), g_strdup ("1"));
+	}
+}
+
+static void
+get_current_children (gpointer key, gpointer value, gpointer list)
+{
+	guint i;
+	guint length;
+	gchar **token;
+	gchar *children;
+	GHashTable *component_ht;
+	ChildrenList *children_list = list;
+	if (!key || !value || !list || !children_list->context_ht || \
+	    !children_list->tmp_ht)
+		return;
+	g_print ("Status: %d\n", g_hash_table_lookup_extended (children_list->context_ht, key,
+							       NULL, NULL));
+	if (g_hash_table_lookup_extended (children_list->context_ht, key,
+					  NULL, (gpointer) &component_ht)) {
+		children = get_property (component_ht, "children", NULL);
+		if (!children)
+			return;
+		g_print ("Children: %s\n", children);
+		token = g_strsplit (children, " ", 0);
+		if (token) {
+			length = g_strv_length (token);
+			for (i = 0; i < length; i++) {
+				g_hash_table_insert (children_list->tmp_ht,
+						     g_strdup (token [i]),
+						     // Initialize the value
+						     // as 0, for yet to traverse
+						     g_strdup ("0"));
+			}
+			g_strfreev (token);
+		}
+	}
+}
+
+static gboolean
+all_node_traversed (gpointer key, gpointer value, gpointer list)
+{
+	if (!key || !value)
+		return FALSE;
+	if (g_utf8_collate (value, "0") == 0)
+		return TRUE;
+	return FALSE;
+}
+
+static gchar*
+get_matching_child (LDTPClientContext *cctxt, GHashTable *context,
+		    gchar *component, gchar *role, gchar *parent,
+		    LDTPErrorCode *err)
+{
+	guint i;
+	guint length;
+	char *data = NULL;
+	gchar *children = NULL;
+	gchar **token   = NULL;
+	ChildrenList children_list;
+	MatchingList matching_list;
+	GHashTable *tmp_ht = NULL;
+	GHashTable *context_ht = context;
+	GHashTable *matched_children = NULL;
+	gboolean all_childrens_traversed = FALSE;
+	GHashTable *component_ht = get_object_def (context, parent, NULL,
+				       cctxt->log_fp, FALSE);
+	if (!component_ht) {
+		update_cur_window_appmap_handle (cctxt,
+						 err);
+		context_ht = get_object_def (cctxt->app_map,
+					     (char *)cctxt->req->context,
+					     NULL, cctxt->log_fp, TRUE);
+		if (context_ht)
+			component_ht = get_object_def (context_ht, parent,
+						       NULL, cctxt->log_fp,
+						       FALSE);
+		if (!component_ht) {
+			g_print ("Unable to find component\n");
+			*err = LDTP_ERROR_UNABLE_TO_GET_COMPONENT_HANDLE;
+			g_print ("%s\n", ldtp_error_get_message (*err));
+			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
+			return NULL;
+		}
+	}
+	children = get_property (component_ht, "children", cctxt->log_fp);
+	if (!children) {
+		g_print ("Current component doesn't have any children\n");
+		*err = LDTP_ERROR_UNABLE_TO_GET_PROPERTY;
+		g_print ("%s\n", ldtp_error_get_message (*err));
+		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
+		return NULL;
+	}
+	token = g_strsplit (children, " ", 0);
+	matched_children = g_hash_table_new_full (&g_str_hash, &g_str_equal,
+						  destroy_string, destroy_string);
+	tmp_ht = g_hash_table_new_full (&g_str_hash, &g_str_equal,
+					destroy_string, destroy_string);
+
+	if (token) {
+		length = g_strv_length (token);
+		for (i = 0; i < length; i++) {
+			g_hash_table_insert (matched_children,
+					     g_strdup (token [i]),
+					     // Initialize the value
+					     // as 0, for yet to traverse
+					     g_strdup ("0"));
+		}
+		g_strfreev (token);
+	}
+	// Make a copy of tmp_ht to matched_children, for iteration
+	g_hash_table_foreach (matched_children, copy_hash_table, tmp_ht);
+	if (tmp_ht == NULL) {
+		g_print ("Unable to copy hash table\n");
+		g_hash_table_destroy (matched_children);
+		return NULL;
+	}
+	// Base ht of the current context
+	children_list.context_ht = context_ht;
+	while (all_childrens_traversed == FALSE) {
+		// New childrens will be added to this list
+		children_list.tmp_ht = tmp_ht;
+		// Get all current nodes children
+		g_print ("Get current node children\n");
+		g_hash_table_foreach (matched_children, get_current_children,
+				      (gpointer) &children_list);
+		tmp_ht = children_list.tmp_ht;
+		// If tmp_ht key is in matched_children list, then
+		// mark the value as traversed (1)
+		g_print ("Set traversed to matching children\n");
+		g_hash_table_foreach (matched_children, set_traversed, tmp_ht);
+		// Destroy existing copy of matched_children
+		g_print ("Destroy matched children\n");
+		g_hash_table_destroy (matched_children);
+		// Create new ht
+		matched_children = g_hash_table_new_full (&g_str_hash,
+							  &g_str_equal,
+							  destroy_string,
+							  destroy_string);
+		// Make a copy of tmp_ht to matched_children, for next iteration
+		g_print ("Copy tmp_ht to matched_children\n");
+		g_hash_table_foreach (tmp_ht, copy_hash_table, matched_children);
+		g_print ("Check all traversed node\n");
+		if (!g_hash_table_find (tmp_ht, all_node_traversed, NULL)) {
+			// If all nodes are traversed, then NULL will
+			// be returned, let us exit by that time
+			all_childrens_traversed = TRUE;
+		}
+	}
+	g_hash_table_destroy (tmp_ht);
+	if (role && g_utf8_collate (role, "BY PASS GENERATEXML BUG") == 0)
+		g_hash_table_foreach (matched_children, &add_item_to_list,
+				      (gpointer) &data);
+	else {
+		matching_list.data = data;
+		matching_list.name = component == NULL ? NULL :	\
+			g_utf8_collate (component,
+					cctxt->req->context) == 0 ? NULL : component;
+		if (matching_list.name)
+			g_print ("List.Name: %s\n", matching_list.name);
+		matching_list.role = role;
+		matching_list.children_ht = matched_children;
+		g_hash_table_foreach (context_ht,
+				      &add_matching_item_to_list,
+				      (gpointer) &matching_list);
+		data = matching_list.data;
+	}
+	g_hash_table_destroy (matched_children);
+	return data;
+}
+
+
 static void
 update_context_name (LDTPClientContext* cctxt)
 {
@@ -950,6 +1145,7 @@ handle_request (LDTPClientContext* cctxt,
 		return;
 
 	case LDTP_CMD_GENERATEMOUSEEVENT: {
+		SPIBoolean flag;
 		long x = 0, y = 0;
 		gchar *mode = "b1c";
   
@@ -959,7 +1155,11 @@ handle_request (LDTPClientContext* cctxt,
 			y = strtol (cctxt->req->component, NULL, 10);
 		if (cctxt->req->arg_list)
 			mode = g_slist_nth_data (cctxt->req->arg_list, 0);
-		SPI_generateMouseEvent (x, y, mode);
+		flag = SPI_generateMouseEvent (x, y, mode);
+		if (flag)
+			*err = LDTP_ERROR_SUCCESS;
+		else
+			*err = LDTP_ERROR_MOUSE_ACTION_FAILED;
 		return;
 	}
 
@@ -973,6 +1173,24 @@ handle_request (LDTPClientContext* cctxt,
 		set_new_context ((char *)cctxt->req->context, (char *)cctxt->req->component);
 		return;
 
+	case LDTP_CMD_WINDOWUPTIME: {
+		GHashTable *window_up_time;
+		if (g_hash_table_lookup_extended (window_duration, cctxt->req->context,
+						  NULL, (gpointer) &window_up_time)) {
+			char *start_time = g_hash_table_lookup (window_up_time, "start_time");
+			char *end_time = g_hash_table_lookup (window_up_time, "end_time");
+			g_print ("WINDOWUPTIME: %s %s\n",
+				 start_time,
+				 end_time);
+			cctxt->resp->data = g_strdup_printf ("%s-%s",
+							     end_time,
+							     start_time);
+			cctxt->resp->data_len = strlen (cctxt->resp->data);
+		} else
+			g_print ("NULL\n");
+		return;
+	}
+
 	case LDTP_CMD_RELEASECONTEXT:
 		release_last_context ();
 		return;
@@ -1100,7 +1318,7 @@ handle_request (LDTPClientContext* cctxt,
 		return;
 
 	case LDTP_CMD_GETAPPLIST: {
-		char *data = NULL;
+		gchar *data = NULL;
 		GHashTable *table;
 		table = get_app_list ();
 		if (table) {
@@ -1144,7 +1362,7 @@ handle_request (LDTPClientContext* cctxt,
 		return;
 	}
 	case LDTP_CMD_GETWINDOWLIST: {
-		char *data = NULL;
+		gchar *data = NULL;
 		GHashTable *table;
 		table = get_window_name_list ();
 		if (table) {
@@ -1261,6 +1479,7 @@ handle_request (LDTPClientContext* cctxt,
 		char *data = NULL;
 		char *name = g_strdup (cctxt->req->component);
 		char *role = NULL;
+		char *parent = NULL;
 		MatchingList list;
 		GHashTable *context_ht = NULL;
 
@@ -1307,20 +1526,36 @@ handle_request (LDTPClientContext* cctxt,
 			return;
 		}
 		role = g_slist_nth_data (cctxt->req->arg_list, 0);
-		list.data = data;
-		list.name = name == NULL ? NULL : g_utf8_collate (name,
-								  cctxt->req->context) == 0 ? NULL : name;
-		if (list.name)
-			g_print ("List.Name: %s\n", list.name);
-		list.role = role;
-		g_hash_table_foreach (context_ht, &add_matching_item_to_list, (gpointer) &list);
-		cctxt->resp->data = list.data;
+		parent = g_slist_nth_data (cctxt->req->arg_list, 1);
+		if (parent)
+			g_print ("Parent: %s\n", parent);
+		if (parent != NULL && g_utf8_collate (parent, "") != 0) {
+			cctxt->resp->data = get_matching_child (cctxt,
+								context_ht,
+								name,
+								role, parent,
+								err);
+		} else {
+			list.data = data;
+			list.name = name == NULL ? NULL : \
+				g_utf8_collate (name,
+						cctxt->req->context) == 0 ? NULL : name;
+			if (list.name)
+				g_print ("List.Name: %s\n", list.name);
+			list.role = role;
+			list.children_ht = NULL;
+			g_hash_table_foreach (context_ht,
+					      &add_matching_item_to_list,
+					      (gpointer) &list);
+			cctxt->resp->data = list.data;
+		}
 		if (cctxt->resp->data) {
 			char *tmp = NULL;
 			/*
 			  FRAME the output in XML format
 			*/
-			tmp = g_strdup_printf ("%s<OBJECTLIST>%s</OBJECTLIST>", XML_HEADER, cctxt->resp->data);
+			tmp = g_strdup_printf ("%s<OBJECTLIST>%s</OBJECTLIST>",
+					       XML_HEADER, cctxt->resp->data);
 			if (tmp) {
 				g_free (cctxt->resp->data);
 				cctxt->resp->data = tmp;
@@ -1331,12 +1566,15 @@ handle_request (LDTPClientContext* cctxt,
 				g_free (cctxt->resp->data);
 				*err = LDTP_ERROR_UNABLE_TO_GET_CHILD_WITH_PROVIDED_ROLE;
 				g_print ("%s\n", ldtp_error_get_message (*err));
-				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
+				log_msg (LDTP_LOG_CAUSE,
+					 ldtp_error_get_message (*err),
+					 cctxt->log_fp);
 			}
 		} else {
 			*err = LDTP_ERROR_UNABLE_TO_GET_CHILD_WITH_PROVIDED_ROLE;
 			g_print ("%s\n", ldtp_error_get_message (*err));
-			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
+			log_msg (LDTP_LOG_CAUSE,
+				 ldtp_error_get_message (*err), cctxt->log_fp);
 		}
 		if (name)
 			g_free (name);
@@ -1440,10 +1678,10 @@ handle_request (LDTPClientContext* cctxt,
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
 			return;
 		}
-		if (!cctxt->app_map) {
+		if (cctxt && !cctxt->app_map) {
                         /* if appmap not already initialised, do it now */
                         accessible = ldtp_gui_get_gui_handle (cctxt, err);
-			if (accessible->handle != cctxt->app_handle)
+			if (accessible && cctxt && accessible->handle != cctxt->app_handle)
 				ldtp_gui_free_gui_handle (accessible);
                         if (*err != LDTP_ERROR_SUCCESS) {
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (*err), cctxt->log_fp);
@@ -1626,6 +1864,12 @@ handle_request (LDTPClientContext* cctxt,
 		*err = radio_menu_item_main (cctxt, cctxt->req->command);
 		break;
 
+#ifdef ENABLE_NEWROLES
+	case SPI_ROLE_LINK:
+		*err = link_main (cctxt, cctxt->req->command);
+		break;
+#endif
+
 	case SPI_ROLE_PUSH_BUTTON:
 		*err = push_button_main (cctxt, cctxt->req->command);
 		break;
@@ -1722,6 +1966,10 @@ handle_request (LDTPClientContext* cctxt,
 	case SPI_ROLE_TOOL_BAR:
 		*err = tool_bar_main (cctxt, cctxt->req->command);
 		break;
+		
+	case SPI_ROLE_PROGRESS_BAR:
+		*err = progress_bar_main (cctxt, cctxt->req->command);
+		break;
 
 #ifdef ENABLE_ACCESS
 	case SPI_ROLE_TITLE_BAR:
@@ -1745,9 +1993,9 @@ handle_request (LDTPClientContext* cctxt,
 		if (cctxt->req->command == LDTP_CMD_KBDENTER) {
 			*err = device_main (cctxt, cctxt->req->command);
 			break;
-		}
-		else if (cctxt->req->command == LDTP_CMD_GRABFOCUS) {
-			AccessibleComponent *accessibleComponent = Accessible_getComponent (cctxt->gui_handle->handle);
+		} else if (cctxt->req->command == LDTP_CMD_GRABFOCUS) {
+			AccessibleComponent *accessibleComponent;
+			accessibleComponent = Accessible_getComponent (cctxt->gui_handle->handle);
 			if (accessibleComponent && cctxt->req->context) {
 				g_print ("Window: %s - GrabFocus\n", cctxt->req->context);
 				if (AccessibleComponent_grabFocus (accessibleComponent) == TRUE)
@@ -1759,6 +2007,16 @@ handle_request (LDTPClientContext* cctxt,
 			}
 			*err = LDTP_ERROR_UNABLE_TO_GRAB_FOCUS;
 			break;
+		} else if (cctxt->req->command == LDTP_CMD_GETOBJECTSIZE) {
+			cctxt->resp->data_len = 0;
+			cctxt->resp->data = get_size (cctxt->gui_handle->handle, err);
+			if (cctxt->resp->data)
+				cctxt->resp->data_len = g_utf8_strlen (cctxt->resp->data, -1);
+			break;
+		} else if (cctxt->req->command == LDTP_CMD_MOUSELEFTCLICK ||
+			   cctxt->req->command == LDTP_CMD_MOUSERIGHTCLICK) {
+			*err = device_main (cctxt, cctxt->req->command);
+			break;
 		}
 		*err = LDTP_ERROR_ROLE_NOT_IMPLEMENTED;
 		g_print ("Role not implemented: %s %d\n", __FILE__, __LINE__);
