@@ -449,12 +449,10 @@ verify_drop_down (Accessible *object, FILE *log_fp)
 			if (focused == 0) {
 				log_msg (LDTP_LOG_CAUSE, "Verify Combo box list child is not focused", log_fp);
 				return LDTP_ERROR_CHILD_NOT_FOCUSSED;
-			}
-			else
+			} else
 				return LDTP_ERROR_SUCCESS;
 		}
-	}
-	else if (child_type == SPI_ROLE_MENU) {
+	} else if (child_type == SPI_ROLE_MENU) {
 		child_object = (Accessible *) get_menu_handle (object);
 		if (child_object) {
 			state = Accessible_getStateSet (object);
@@ -464,12 +462,10 @@ verify_drop_down (Accessible *object, FILE *log_fp)
 			if ((showing == 0) && (visible == 0)) {
 				log_msg (LDTP_LOG_CAUSE, "Verify combo box menu child is not showing", log_fp);
 				return LDTP_ERROR_MENU_NOT_VISIBLE;
-			}
-			else
+			} else
 				return LDTP_ERROR_SUCCESS;
 		}
-	}
-	else {	  
+	} else {	  
 		log_msg (LDTP_LOG_CAUSE, "Verify combo box click child type is unidentified", log_fp);
 		return LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED;
 	}
@@ -564,8 +560,7 @@ verify_set_text_value (LDTPClientContext* cctxt)
 				return LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED;
 			}
 			return LDTP_ERROR_SUCCESS;
-		}
-		else {
+		} else {
 			g_print ("Verify Combo box SetTextValue child object is NULL\n");
 			log_msg (LDTP_LOG_CAUSE, "Verify Combo box SetTextValue child object is NULL", cctxt->log_fp);
 			return LDTP_ERROR_VERIFY_SETTEXTVALUE_FAILED;
@@ -575,7 +570,8 @@ verify_set_text_value (LDTPClientContext* cctxt)
 		char *name = Accessible_getName (object);
 		if (name) {
 			if (cctxt && cctxt->req && cctxt->req->arg_list &&
-			    cctxt->req->arg_list->data && (g_utf8_collate (cctxt->req->arg_list->data, name) == 0)) {
+			    cctxt->req->arg_list->data &&
+			    (g_utf8_collate (cctxt->req->arg_list->data, name) == 0)) {
 				g_print ("Name: %s - %s\n", name, (char *)cctxt->req->arg_list->data);
 				flag = TRUE;
 			}
@@ -711,15 +707,13 @@ get_text_value (LDTPClientContext* cctxt)
 			cctxt->resp->data = g_strdup (cctxt->req->arg_list->data);
 			cctxt->req->arg_list = g_slist_remove (cctxt->req->arg_list->data, cctxt->resp->data);
 			return LDTP_ERROR_SUCCESS;
-		}
-		else {
+		} else {
 			log_msg (LDTP_LOG_CAUSE, 
 				 "Combo box gettextvalue  action failed",
 				 cctxt->log_fp);
 			return LDTP_ERROR_GETTEXTVALUE_FAILED;
 		}
-	}
-	else if (type == SPI_ROLE_MENU) {
+	} else if (type == SPI_ROLE_MENU) {
 		child = Accessible_getText (object);
 		item = AccessibleText_getText (child, 0, LONG_MAX);
 		cctxt->resp->data = g_strdup (item);
@@ -727,8 +721,7 @@ get_text_value (LDTPClientContext* cctxt)
 		SPI_freeString (item);
 		Accessible_unref (child);
 		return LDTP_ERROR_SUCCESS;
-	}
-	else {
+	} else {
 		log_msg (LDTP_LOG_CAUSE, "Combo box child type is unidentified", cctxt->log_fp);
 		return LDTP_ERROR_CHILD_TYPE_UNIDENTIFIED;
 	}
