@@ -260,6 +260,14 @@ search_key_based (gpointer key, gpointer value, gpointer user_data)
 		}
 		if (obj->parent_name && value) {
 			gchar *parent = get_property (value, "parent", NULL);
+			if (parent == NULL) {
+				// Only the window's parent can be
+				// empty in current hash table, so let
+				// us consider that the requested key
+				// is window name
+				g_print ("Parent NULL\n");
+				return TRUE;
+			}
 			if (parent && g_pattern_match_simple (obj->parent_name, parent))
 				return TRUE;
 		} else
@@ -290,6 +298,14 @@ search_obj_based_on_index (gpointer key, gpointer value, gpointer user_data)
 	if (obj_index && g_pattern_match_simple (obj->key, obj_index)) {
 		if (obj->parent_name) {
 			gchar *parent = get_property (value, "parent", NULL);
+			if (parent == NULL) {
+				// Only the window's parent can be
+				// empty in current hash table, so let
+				// us consider that the requested key
+				// is window name
+				g_print ("Parent NULL\n");
+				return TRUE;
+			}
 			if (parent && g_pattern_match_simple (obj->parent_name, parent))
 				return TRUE;
 		} else
@@ -324,6 +340,14 @@ search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 			if (g_pattern_match_string (obj->pattern, key)) {
 				if (obj->parent_name && value) {
 					gchar *parent = get_property (value, "parent", NULL);
+					if (parent == NULL) {
+						// Only the window's parent can be
+						// empty in current hash table, so let
+						// us consider that the requested key
+						// is window name
+						g_print ("Parent NULL\n");
+						return TRUE;
+					}
 					if (parent && g_pattern_match_simple (obj->parent_name, parent))
 						return TRUE;
 				} else
@@ -336,6 +360,14 @@ search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 			tmp = NULL;
 			if (obj->parent_name && value) {
 				gchar *parent = get_property (value, "parent", NULL);
+				if (parent == NULL) {
+					// Only the window's parent can be
+					// empty in current hash table, so let
+					// us consider that the requested key
+					// is window name
+					g_print ("Parent NULL\n");
+					return TRUE;
+				}
 				if (parent && g_pattern_match_simple (obj->parent_name, parent))
 					return TRUE;
 			} else
@@ -349,6 +381,14 @@ search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 			tmp = NULL;
 			if (obj->parent_name && value) {
 				gchar *parent = get_property (value, "parent", NULL);
+				if (parent == NULL) {
+					// Only the window's parent can be
+					// empty in current hash table, so let
+					// us consider that the requested key
+					// is window name
+					g_print ("Parent NULL\n");
+					return TRUE;
+				}
 				if (parent && g_pattern_match_simple (obj->parent_name, parent))
 					return TRUE;
 			} else
@@ -362,6 +402,13 @@ search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 			tmp = NULL;
 			if (obj->parent_name && value) {
 				gchar *parent = get_property (value, "parent", NULL);
+				if (parent == NULL) {
+					// Only the window's parent can be
+					// empty in current hash table, so let
+					// us consider that the requested key
+					// is window name
+					return TRUE;
+				}
 				if (parent && g_pattern_match_simple (obj->parent_name, parent))
 					return TRUE;
 			} else
@@ -375,6 +422,14 @@ search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 			tmp = NULL;
 			if (obj->parent_name && value) {
 				gchar *parent = get_property (value, "parent", NULL);
+				if (parent == NULL) {
+					// Only the window's parent can be
+					// empty in current hash table, so let
+					// us consider that the requested key
+					// is window name
+					g_print ("Parent NULL\n");
+					return TRUE;
+				}
 				if (parent && g_pattern_match_simple (obj->parent_name, parent))
 					return TRUE;
 			} else
@@ -388,6 +443,14 @@ search_key_glob_based (gpointer key, gpointer value, gpointer user_data)
 		gboolean flag = g_pattern_match_string (obj->pattern, key);
 		if (flag && obj->parent_name && value) {
 			gchar *parent = get_property (value, "parent", NULL);
+			if (parent == NULL) {
+				// Only the window's parent can be
+				// empty in current hash table, so let
+				// us consider that the requested key
+				// is window name
+				g_print ("Parent NULL\n");
+				return TRUE;
+			}
 			if (parent && g_pattern_match_simple (obj->parent_name, parent))
 				return TRUE;
 		} else
@@ -450,6 +513,14 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 			if (g_utf8_collate (label, tmp_data) == 0) {
 				if (obj->parent_name && value) {
 					gchar *parent = get_property (value, "parent", NULL);
+					if (parent == NULL) {
+						// Only the window's parent can be
+						// empty in current hash table, so let
+						// us consider that the requested key
+						// is window name
+						g_print ("Parent NULL\n");
+						return TRUE;
+					}
 					if (parent && g_pattern_match_simple (obj->parent_name, parent))
 						return TRUE;
 				} else
@@ -467,6 +538,14 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 					gchar *parent = get_property (value, "parent", NULL);
 					if (parent)
 						g_print ("Parent: %s - %s\n", parent, obj->parent_name);
+					if (parent == NULL) {
+						// Only the window's parent can be
+						// empty in current hash table, so let
+						// us consider that the requested key
+						// is window name
+						g_print ("Parent NULL\n");
+						return TRUE;
+					}
 					if (parent && g_pattern_match_simple (obj->parent_name, parent))
 						return TRUE;
 				} else
@@ -484,6 +563,14 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 			if (g_utf8_collate (label_by, tmp_data) == 0) {
 				if (obj->parent_name && value) {
 					gchar *parent = get_property (value, "parent", NULL);
+					if (parent == NULL) {
+						// Only the window's parent can be
+						// empty in current hash table, so let
+						// us consider that the requested key
+						// is window name
+						g_print ("Parent NULL\n");
+						return TRUE;
+					}
 					if (parent && g_pattern_match_simple (obj->parent_name, parent))
 						return TRUE;
 				} else
@@ -499,6 +586,14 @@ search_label_based (gpointer key, gpointer value, gpointer user_data)
 				tmp = NULL;
 				if (obj->parent_name && value) {
 					gchar *parent = get_property (value, "parent", NULL);
+					if (parent == NULL) {
+						// Only the window's parent can be
+						// empty in current hash table, so let
+						// us consider that the requested key
+						// is window name
+						g_print ("Parent NULL\n");
+						return TRUE;
+					}
 					if (parent && g_pattern_match_simple (obj->parent_name, parent))
 						return TRUE;
 				} else
@@ -556,6 +651,14 @@ search_label_glob_based (gpointer key, gpointer value, gpointer user_data)
 			gboolean tmp_flag = g_pattern_match_string (obj->pattern, tmp_label);
 			if (tmp_flag && obj->parent_name && value) {
 				gchar *parent = get_property (value, "parent", NULL);
+				if (parent == NULL) {
+					// Only the window's parent can be
+					// empty in current hash table, so let
+					// us consider that the requested key
+					// is window name
+					g_print ("Parent NULL\n");
+					return TRUE;
+				}
 				if (parent && g_pattern_match_simple (obj->parent_name, parent))
 					return TRUE;
 			} else
@@ -569,6 +672,14 @@ search_label_glob_based (gpointer key, gpointer value, gpointer user_data)
 			gboolean tmp_flag = g_pattern_match_string (obj->pattern, tmp_label_by);
 			if (tmp_flag && obj->parent_name && value) {
 				gchar *parent = get_property (value, "parent", NULL);
+				if (parent == NULL) {
+					// Only the window's parent can be
+					// empty in current hash table, so let
+					// us consider that the requested key
+					// is window name
+					g_print ("Parent NULL\n");
+					return TRUE;
+				}
 				if (parent && g_pattern_match_simple (obj->parent_name, parent))
 					return TRUE;
 			} else
@@ -971,8 +1082,7 @@ get_property (GHashTable *ht, gchar *property, FILE *log_fp)
 		g_sprintf (msg, "Property %s not found in appmap", property);
 		g_print ("%s\n", msg);
 		log_msg (LDTP_LOG_DEBUG, msg, log_fp);
-	}
-	else
+	} else
 		g_print ("Property: %s - Value: %s\n", property, value);
 	return value;
 }
