@@ -93,6 +93,10 @@ enum _LDTPCommandId {
 	LDTP_CMD_INSERTTEXT,
 	LDTP_CMD_INVALID,
 	LDTP_CMD_INVOKEMENU,
+	LDTP_CMD_ISCHILDINDEXSELECTED,
+	LDTP_CMD_ISCHILDITEMINDEXSELECTED,
+	LDTP_CMD_ISCHILDITEMSELECTED,
+	LDTP_CMD_ISCHILDSELECTED,
 	LDTP_CMD_ISTEXTSTATEENABLED,
 	LDTP_CMD_KBDENTER,
 	LDTP_CMD_KEYPRESS,
@@ -123,7 +127,9 @@ enum _LDTPCommandId {
 	LDTP_CMD_SCROLLLEFT,
 	LDTP_CMD_SCROLLRIGHT,
 	LDTP_CMD_SCROLLUP,
+	LDTP_CMD_SELECTALL,
 	LDTP_CMD_SELECTCALENDARDATE,
+	LDTP_CMD_SELECTEDITEMCOUNT,
 	LDTP_CMD_SELECTEVENT,
 	LDTP_CMD_SELECTEVENTINDEX,
 	LDTP_CMD_SELECTINDEX,
@@ -162,6 +168,10 @@ enum _LDTPCommandId {
 	LDTP_CMD_TITLEBARSELECTMENUITEM,
 	LDTP_CMD_UNCHECK,
 	LDTP_CMD_UNCHECKROW,
+	LDTP_CMD_UNSELECTALL,
+	LDTP_CMD_UNSELECTINDEX,
+	LDTP_CMD_UNSELECTITEM,
+	LDTP_CMD_UNSELECTITEMINDEX,
 	LDTP_CMD_VERIFYBUTTONCOUNT,
 	LDTP_CMD_VERIFYCHECK,
 	LDTP_CMD_VERIFYCHECKROW,
@@ -172,6 +182,8 @@ enum _LDTPCommandId {
 	LDTP_CMD_VERIFYMENUUNCHECK, 
 	LDTP_CMD_VERIFYPARTIALMATCH,
 	LDTP_CMD_VERIFYPARTIALTABLECELL,
+	LDTP_CMD_VERIFYPROGRESSBAR,
+	LDTP_CMD_VERIFYPROGRESSBARVISIBLE,
 	LDTP_CMD_VERIFYPUSHBUTTON,
 	LDTP_CMD_VERIFYSCROLLBAR,
 	LDTP_CMD_VERIFYSCROLLBARHORIZONTAL,
@@ -192,7 +204,8 @@ enum _LDTPCommandId {
 	LDTP_CMD_VERIFYUNCHECKROW,
 	LDTP_CMD_VERIFYVISIBLEBUTTONCOUNT,
 	LDTP_CMD_WAITTILLGUIEXIST,
-	LDTP_CMD_WAITTILLGUINOTEXIST
+	LDTP_CMD_WAITTILLGUINOTEXIST,
+	LDTP_CMD_WINDOWUPTIME
 };
 
 #endif
