@@ -176,6 +176,12 @@ ldtp_error_get_message (LDTPErrorCode error)
 	case LDTP_ERROR_CHILD_NOT_FOCUSSED:
 		msg = "Verification of DropDown failed on the mentioned object as object's list is not in focus";
 		break;
+	case LDTP_ERROR_CHILD_NOT_SELECTED:
+		msg = "Child not selected";
+		break;
+	case LDTP_ERROR_UNABLE_TO_GET_SELECTED_ITEM_COUNT:
+		msg = "Unable to get selected item count";
+		break;
 	case LDTP_ERROR_MENU_VISIBLE:
 		msg = "Verification of HideList failed on the mentioned object as object's menu is visible";
 		break;
@@ -250,11 +256,14 @@ ldtp_error_get_message (LDTPErrorCode error)
 	case LDTP_ERROR_UNABLE_TO_SELECT_LAYERED_PANE_ITEM:
 		msg = "Unable to select item in layered pane";
 		break;
+	case LDTP_ERROR_UNABLE_TO_DESELECT_LAYERED_PANE_ITEM:
+		msg = "Unable to deselect item in layered pane";
+		break;
 	case LDTP_ERROR_UNABLE_TO_SELECT_TEXT_ITEM:
 		msg = "Unable to select text item in the list";
 		break;
-	case LDTP_ERROR_LIST_INDEX_GREATER:
-		msg = "List index value is greater than available index";
+	case LDTP_ERROR_LIST_INDEX_INCORRECT:
+		msg = "List index value is less than or greater than available index";
 		break;
 	case LDTP_ERROR_UNABLE_TO_GET_SELECTED_CHILD:
 		msg = "Unable to get the selected child item from the list";
@@ -538,6 +547,9 @@ ldtp_error_get_message (LDTPErrorCode error)
         case LDTP_ERROR_UNABLE_TO_MOVE_MOUSE:
                 msg = "Mouse Cursor move failed";
                 break;
+        case LDTP_ERROR_MOUSE_ACTION_FAILED:
+                msg = "Mouse action failed";
+                break;
 	case LDTP_ERROR_INVALID_FORMAT:
 		msg = "Invalid Format";
 		break;
@@ -595,6 +607,9 @@ ldtp_error_get_message (LDTPErrorCode error)
 	case LDTP_ERROR_SET_APP_UNDER_TEST_NAME_FAILED:
 		msg = "Setting application name under test failed";
 		break;
+	case LDTP_ERROR_PROGRESSBAR_NOT_VISIBLE:
+		msg = "Status bar not visible";
+		break;
 	default:
 		msg = "Error code not found";
 		break;
