@@ -75,6 +75,8 @@ typedef enum _LDTPErrorCode {
 	LDTP_ERROR_RIGHT_CLICK_FAILED,
 	LDTP_ERROR_CHILD_IN_FOCUS,
 	LDTP_ERROR_CHILD_NOT_FOCUSSED,
+	LDTP_ERROR_CHILD_NOT_SELECTED,
+	LDTP_ERROR_UNABLE_TO_GET_SELECTED_ITEM_COUNT,
 	LDTP_ERROR_UNABLE_TO_GET_MENU_HANDLE,
 	LDTP_ERROR_UNABLE_TO_FIND_POPUP_MENU,
 	LDTP_ERROR_MENU_VISIBLE,
@@ -101,8 +103,9 @@ typedef enum _LDTPErrorCode {
 	LDTP_ERROR_UNABLE_TO_SELECT_LABEL,
 	LDTP_ERROR_LABEL_NOT_FOUND,
 	LDTP_ERROR_UNABLE_TO_SELECT_LAYERED_PANE_ITEM,
+	LDTP_ERROR_UNABLE_TO_DESELECT_LAYERED_PANE_ITEM,
 	LDTP_ERROR_UNABLE_TO_SELECT_TEXT_ITEM,
-	LDTP_ERROR_LIST_INDEX_GREATER,
+	LDTP_ERROR_LIST_INDEX_INCORRECT,
 	LDTP_ERROR_UNABLE_TO_GET_SELECTED_CHILD,
 	LDTP_ERROR_UNABLE_TO_SELECT_CHILD,
 	LDTP_ERROR_UNABLE_TO_GET_CHILD_MENU_ITEM,
@@ -193,6 +196,7 @@ typedef enum _LDTPErrorCode {
 	LDTP_ERROR_UNABLE_TO_STAT_DIR,
 	LDTP_ERROR_ROLE_NOT_IMPLEMENTED,
 	LDTP_ERROR_UNABLE_TO_MOVE_MOUSE,
+	LDTP_ERROR_MOUSE_ACTION_FAILED,
 	LDTP_ERROR_INVALID_FORMAT,
 	LDTP_ERROR_TOKEN_NOT_FOUND,
 	LDTP_ERROR_UNABLE_TO_ENTER_KEY,
@@ -213,7 +217,8 @@ typedef enum _LDTPErrorCode {
 	LDTP_ERROR_UNABLE_TO_GET_WINDOW_LIST,
 	LDTP_ERROR_UNABLE_TO_SET_SLIDER_VALUE,
 	LDTP_ERROR_UNABLE_TO_GET_OBJECT_STATE,
-	LDTP_ERROR_SET_APP_UNDER_TEST_NAME_FAILED
+	LDTP_ERROR_SET_APP_UNDER_TEST_NAME_FAILED,
+	LDTP_ERROR_PROGRESSBAR_NOT_VISIBLE
 } LDTPErrorCode;
 
 const char* ldtp_error_get_message (LDTPErrorCode error);
