@@ -108,7 +108,7 @@ static struct {
 
 	{0, {0}}, //PASSWORD_TEXT 39
 	{0, {0}}, //POPUP_MENU 40
-	{0, {0}}, //PROGRESS_BAR 41
+	{4, { SPI_STATE_ENABLED, SPI_STATE_SENSITIVE, SPI_STATE_SHOWING, SPI_STATE_VISIBLE }}, //PROGRESS_BAR 41
 
 	{4, { SPI_STATE_ENABLED, SPI_STATE_VISIBLE, SPI_STATE_SENSITIVE, SPI_STATE_SHOWING}}, //PUSH_BUTTON 42
 
@@ -236,10 +236,27 @@ trace_path_to_parent (GHashTable *context, char *context_name,
 		}
 		if (*class_type == NULL)
 			*class_type = get_property (component, "class", log_fp);
+		g_print ("Pushing property: %s\n", prop);
 		push (head, atoi (prop));
 		parent_name = get_property (component, "parent", log_fp);
 		if (ldtp_debug && parent_name && context_name)
 			g_print ("Parent name: %s - Context name: %s\n", parent_name, context_name);
+		prop = get_property (component, "class", log_fp);
+		g_print ("Class **** : %s\n", prop);
+		if (g_utf8_collate ("frame", prop) == 0 ||
+		    g_utf8_collate ("dialog", prop) == 0 ||
+		    g_utf8_collate ("alert", prop) == 0 ||
+		    g_utf8_collate ("file_chooser", prop) == 0 ||
+		    g_utf8_collate ("font_chooser", prop) == 0 ||
+		    g_utf8_collate ("color_chooser", prop) == 0) {
+			// Since we have reached the current window
+			// top level hierarchy, let us return, also
+			// when context and component is same
+			pop (head);
+			// Only when context and component are same
+			push (head, -2);
+			return head;
+		}
 		while (1) {
 			if (g_utf8_strchr (context_name, -1, ' ') != NULL) {
 				char *str = escape_character (context_name, ' ');
@@ -264,13 +281,19 @@ trace_path_to_parent (GHashTable *context, char *context_name,
 					return NULL;
 				}
 				push (head, atoi (prop));
+				g_print ("Pushing property: %s\n", prop);
+				prop = get_property (component, "child_index", log_fp);
 				parent_name = get_property (component, "parent", log_fp);
 				if (ldtp_debug && parent_name && context_name)
 					g_print ("InsideWhile: Parent name: %s - Context name: %s - child index: %s\n",
 						 parent_name, context_name, prop);
-			}
-			else
+				prop = get_property (component, "class", log_fp);
+				g_print ("Class **** : %s\n", prop);
+			} else {
+				g_print ("Unable to get component name of parent: %s\n",
+					 parent_name);
 				break;
+			}
 		}
 	}
 	return head;
@@ -807,6 +830,11 @@ get_accessible_component_handle (struct node *head, Accessible *context, FILE *l
 		return NULL;
 	}
 	i = pop (head);
+	if (i == -2) {
+		// When context and component are same
+		Accessible_ref (context);
+		return context;
+	}
 	parent = context;
 	while (i != -1) {
 		child = Accessible_getChildAtIndex (parent, i);
@@ -923,9 +951,9 @@ is_object_matching (Accessible *object, GHashTable *comp_attributes, FILE *log_f
 	char *accessible_label;
 	char *hash_label;
 #ifdef ENABLE_LOCALIZATION
-	gchar *value;
+	gchar *value = NULL;
 #else
-	gint value;
+	gint value = 0;
 #endif
 	/*
 	 * NOTE: Checking if the obtained object is the required one 
@@ -1924,8 +1952,9 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 		cctxt->app_handle = get_window_handle (NULL, cctxt->app_under_test,
 						       context, NULL, NULL);
 	if (!cctxt->app_handle) {
-		g_sprintf (msg, "Application: %s not running", app_name);
-		*err = LDTP_ERROR_APP_NOT_RUNNING;
+		g_print ("%s - %d - Window %s not open\n", __FILE__, __LINE__, context);
+		g_sprintf (msg, "Window %s not open", context);
+		*err = LDTP_ERROR_WIN_NOT_OPEN;
 		goto error;
 	}
 
@@ -2102,8 +2131,7 @@ ldtp_gui_get_gui_handle (LDTPClientContext* cctxt,
 		else if (g_ascii_strcasecmp (name, "calendar event") == 0)
 			ctxt_handle->class_id = CALENDAR_EVENT;
 		SPI_freeString (name);
-	}
-	else
+	} else
 		ctxt_handle->class_id = class;
 
 	g_print ("Class id: %d\n", ctxt_handle->class_id);
