@@ -162,12 +162,15 @@ int release_last_context (void);
 GHashTable *get_app_list (void);
 GHashTable *get_window_name_list (void);
 void ldtp_gui_free_gui_handle (LDTPGuiHandle *handle);
-void ldtp_gui_gui_exist (LDTPClientContext* cctxt, LDTPErrorCode* err);
+gchar *get_size (Accessible *accessible, LDTPErrorCode *err);
+void ldtp_gui_gui_exist (LDTPClientContext* cctxt, LDTPErrorCode *err);
+void ldtp_gui_get_window_size (LDTPClientContext* cctxt, LDTPErrorCode* err);
 void ldtp_gui_wait_till_gui_exist (LDTPClientContext* cctxt, LDTPErrorCode* err);
 void ldtp_gui_wait_till_gui_not_exist (LDTPClientContext* cctxt, LDTPErrorCode* err);
 void update_cur_window_appmap_handle (LDTPClientContext* cctxt, LDTPErrorCode* err);
 void update_cur_context_appmap_handle (LDTPClientContext* cctxt, LDTPErrorCode* err);
 LDTPErrorCode grab_focus (Accessible *object, FILE *log_fp);
-Accessible *get_window_handle (Accessible *app_handle, char *context, char **window_name, gboolean *flag);
+Accessible *get_window_handle (Accessible *app_handle, char *app_name, char *context,
+			       char **window_name, gboolean *flag);
 
 #endif /*__GUI_H__*/
