@@ -50,9 +50,12 @@ int script_listener = 0;               // listening socket descriptor
 char*
 get_tmp_file (int server_type)
 {
-	if (server_type == LDTP_SCRIPT_SERVER)
-		return g_strdup_printf ("/tmp/ldtp-%s-%s", getenv ("USER"), getenv ("DISPLAY"));
-	else
+	if (server_type == LDTP_SCRIPT_SERVER) {
+		if (getenv ("USER"))
+			return g_strdup_printf ("/tmp/ldtp-%s-%s", getenv ("USER"), getenv ("DISPLAY"));
+		else
+			return g_strdup_printf ("/tmp/ldtp-%s-%s", getenv ("LOGNAME"), getenv ("DISPLAY"));
+	} else
 		return NULL;
 }
 
