@@ -34,6 +34,7 @@
 #include "client-handler.h"
 #include "ldtp-error.h"
 #include "ldtp-logger.h"
+#include "device.h"
 
 #ifndef ENABLE_GOPTIONPARSE
 #include <getopt.h>
@@ -57,6 +58,7 @@ pthread_mutex_t cb_mutex = PTHREAD_MUTEX_INITIALIZER;
 pthread_mutex_t client_thread_pool_mutex = PTHREAD_MUTEX_INITIALIZER;
 static char *env_ldtp_debug;
 static char *env_ldtp_debug_file;
+GHashTable *window_duration = NULL;
 
 #ifdef ENABLE_GOPTIONPARSE
 static GOptionEntry entries [] = 
@@ -97,74 +99,119 @@ is_window_in_cctxt (char *window_name)
 	return cctxt;
 }
 
+static char*
+get_current_time()
+{
+	char outstr[200];
+	time_t t;
+	struct tm *tmp;
+
+	t = time(NULL);
+	tmp = localtime(&t);
+	if (tmp == NULL)
+		return NULL;
+
+	if (strftime(outstr, sizeof(outstr), "%Y %m %d %H %M %S", tmp) == 0)
+		return NULL;
+
+	return g_strdup (outstr);
+}
+
 static void
 report_window_event  (const AccessibleEvent *event, void *user_data)
 {
 	g_print ("Event type: %s\n", event->type);
-	if (event_notifier && g_ascii_strcasecmp ("window:create", event->type) == 0) {
+	if (g_ascii_strcasecmp ("window:create", event->type) == 0) {
 		uint32_t resp_size = 0;
+		gboolean flag = FALSE;
 		LDTPErrorCode status;
 		char *resp_pckt = NULL;
 		char *window_name = NULL;
 		LDTPClientContext *cctxt = NULL;
 
-		char *context = Accessible_getName (event->source);
 		char *title = AccessibleWindowEvent_getTitleString (event);
-		if (!title) {
-			if (context)
-				SPI_freeString (context);
+		if (!title)
+			return;
+		if (!g_utf8_collate (title, "")) {
+			// FIXME: AC if window did not have name, then we remove all this kinda window now
+			AccessibleRole role = Accessible_getRole (event->source);
+
+			gchar *tmp = g_strdup_printf ("0");
+			if (tmp) {
+				window_name = get_window_name_in_appmap_format (tmp,
+										role);
+				g_free (tmp);
+				tmp = NULL;
+			}
+		} else
+			window_name = get_window_name_in_appmap_format (title,
+									Accessible_getRole (event->source));
+		if (window_name) {
+			char *current_time = get_current_time ();
+			if (current_time) {
+				GHashTable *start_time;
+				start_time = g_hash_table_new_full (&g_str_hash, &g_str_equal,
+								    &destroy_string,
+								    &destroy_string);
+				if (start_time) {
+					g_hash_table_insert (start_time,
+							     g_strdup ("start_time"),
+							     g_strdup (current_time));
+					g_hash_table_insert (start_time,
+							     g_strdup ("end_time"),
+							     g_strdup (current_time));
+				}
+				g_free (current_time);
+				g_hash_table_replace (window_duration,
+						      g_strdup (window_name),
+						      start_time);
+			}
+		} else {
+			SPI_freeString (title);
 			return;
 		}
-		if ((cctxt = is_window_reg_for_events (title))) {
-			/*
-			  Notify to client
-			*/
-			if (!cctxt || !cctxt->resp) {
-				g_print ("CCTXT is lost\n");
-				return;
-			}
-			cctxt->resp->data = g_strdup (title);
-			cctxt->resp->data_len = g_utf8_strlen (title, -1);
-			cctxt->resp->resp_status = LDTP_ERROR_SUCCESS;
-
-			generate_notification_packet (cctxt, &status, &resp_pckt, &resp_size);
-			if (status != LDTP_ERROR_SUCCESS) {
-				g_print ("Error generating notification\n");
-				return;
-			}
-			if (resp_pckt)
-				g_print ("Notification: %s - Len - %d", resp_pckt, resp_size);
-			send_response (cctxt->sock_fd, resp_pckt, resp_size, &status);
-			g_free (cctxt->resp->data);
-			cctxt->resp->data = NULL;
+		cctxt = is_window_reg_for_events (window_name);
+		if (!cctxt) {
+			cctxt = is_window_reg_for_events (title);
+			flag = TRUE;
+		}
+		if (!cctxt || !cctxt->resp) {
+			g_print ("CCTXT is lost\n");
+			g_free (window_name);
+			SPI_freeString (title);
 			return;
 		}
 		/*
-		  If window title is used in old appmap format (like dlgFind), then use the following approach
+		  Notify to client
 		*/
-		window_name = get_window_name_in_appmap_format (title, Accessible_getRole (event->source));
-		if (window_name && is_window_reg_for_events (window_name)) {
-			/*
-			  Notify to client
-			*/
-			if (window_name)
-				g_free (window_name);
-			cctxt->resp->resp_status = LDTP_ERROR_SUCCESS;
+		if (cctxt->resp->data) {
+			g_free (cctxt->resp->data);
+			cctxt->resp->data = NULL;
+		}
+		if (flag) {
+			cctxt->resp->data = g_strdup (title);
+			cctxt->resp->data_len = g_utf8_strlen (title, -1);
+		} else {
+			cctxt->resp->data = g_strdup (window_name);
+			cctxt->resp->data_len = g_utf8_strlen (window_name, -1);
+		}
+		cctxt->resp->resp_status = LDTP_ERROR_SUCCESS;
 
-			generate_notification_packet (cctxt, &status, &resp_pckt, &resp_size);
-			if (status != LDTP_ERROR_SUCCESS) {
-				g_print ("Error generating notification\n");
-				return;
-			}
-
-			g_print ("Notification: %s - Len - %d", resp_pckt, resp_size);
-			send_response (cctxt->sock_fd, resp_pckt, resp_size, &status);
+		generate_notification_packet (cctxt, &status, &resp_pckt, &resp_size);
+		if (status != LDTP_ERROR_SUCCESS) {
+			SPI_freeString (title);
+			g_free (window_name);
+			g_print ("Error generating notification\n");
 			return;
 		}
-		if (window_name)
-			g_free (window_name);
-		SPI_freeString (context);
+		if (resp_pckt)
+			g_print ("Notification: %s - Len - %d", resp_pckt, resp_size);
+		send_response (cctxt->sock_fd, resp_pckt, resp_size, &status);
+		g_free (cctxt->resp->data);
+		cctxt->resp->data = NULL;
 		SPI_freeString (title);
+		g_free (window_name);
+		return;
 	} else if (g_ascii_strcasecmp ("window:close", event->type) == 0 ||
 		   g_ascii_strcasecmp ("window:deactivate", event->type) == 0 ||
 		   g_ascii_strcasecmp ("window:destroy", event->type) == 0) {
@@ -197,8 +244,10 @@ report_window_event  (const AccessibleEvent *event, void *user_data)
 						g_hash_table_remove (cctxt->app_map,
 								     window_name);
 						g_free (window_name);
+						window_name = NULL;
 					} else {
 						g_free (window_name);
+						window_name = NULL;
 						break; // Hash table is indexed by 0
 					}
 				} else {
@@ -212,7 +261,20 @@ report_window_event  (const AccessibleEvent *event, void *user_data)
 		window_name = get_window_name_in_appmap_format (title,
 								Accessible_getRole (event->source));
 		if (window_name) {
-			g_print ("Window name: %s - %s\n", window_name, title);
+			char *current_time = get_current_time ();
+			if (current_time) {
+				GHashTable *end_time = NULL;
+				if (g_hash_table_lookup_extended(window_duration,
+								 window_name,
+								 NULL,
+								 (gpointer) &end_time)) {
+					if (end_time)
+						g_hash_table_replace (end_time,
+								      g_strdup ("end_time"),
+								      g_strdup (current_time));
+				}
+				g_free (current_time);
+			}
 			cctxt = is_window_in_cctxt (window_name);
 			if (cctxt && cctxt->app_map) {
 				if (pthread_mutex_trylock (&cb_mutex) != EBUSY) {
@@ -221,7 +283,9 @@ report_window_event  (const AccessibleEvent *event, void *user_data)
 				}
 			}
 			g_free (window_name);
+			window_name = NULL;
 		}
+
 		SPI_freeString (title);
 	}
 }
@@ -249,6 +313,11 @@ cleanup (int mysig)
 		ldtp_debug_log_fp = NULL;
 	}
 
+	if (window_duration) {
+		g_hash_table_destroy (window_duration);
+		window_duration = NULL;
+	}
+
 	pthread_mutex_lock (&client_thread_pool_mutex);
 	if (event_notifier) {
 		g_hash_table_destroy (event_notifier);
@@ -409,7 +478,7 @@ ldtp_server_thread (void *ptr)
 			}
 		}
 		if ((pfd.revents & POLLIN) && (pfd.fd == server_socket)) {
-			int new_client_fd = accept_connection (server_socket, &err);
+			accept_connection (server_socket, &err);
 			if (err != LDTP_ERROR_SUCCESS)
 				ldtp_log ("******Unable to accept connection*******\n");
 			continue;
@@ -455,7 +524,10 @@ get_log_file_name ()
 	now = time (NULL);
 	tim = *(localtime (&now));
 	i = strftime (s, 30, "%d-%m-%Y", &tim);
-	return g_strdup_printf ("/tmp/ldtp-%s/%s.log", getenv ("USER"), s);
+	if (getenv ("USER"))
+		return g_strdup_printf ("/tmp/ldtp-%s/%s.log", getenv ("USER"), s);
+	else
+		return g_strdup_printf ("/tmp/ldtp-%s/%s.log", getenv ("LOGNAME"), s);
 }
 
 int
@@ -613,6 +685,10 @@ main (int argc, char **argv)
 	env_ldtp_debug = getenv ("LDTP_DEBUG");
 	env_ldtp_debug_file = getenv ("LDTP_DEBUG_LOGFILE");
 
+	window_duration = g_hash_table_new_full (&g_str_hash, &g_str_equal,
+						 &destroy_string,
+						 &destroy_hashtable);
+
 	retval = pthread_create (&server_thread, NULL, &ldtp_server_thread, 
 				 NULL);
 	if (retval == EAGAIN) {
@@ -623,6 +699,10 @@ main (int argc, char **argv)
 	}
 	debug_log_file_name = get_log_file_name ();
 	ldtp_debug_log_fp = fopen (debug_log_file_name, "a");
+
+	/* get the keyboard keycodes from xmodmod -pke */
+	get_keyboard_keycodes();
+
 	spi_init = SPI_init ();
 
 	window_listener = SPI_createAccessibleEventListener (report_window_event, NULL);
