@@ -90,7 +90,7 @@ select_tab (Accessible *object, char *tab_name, FILE *log_fp)
 					return error;
 				}
 				else {
-					return  (LDTP_ERROR_SUCCESS);
+					return LDTP_ERROR_SUCCESS;
 				}
 			}
 			else {
