@@ -104,7 +104,7 @@ push_button_main (LDTPClientContext* cctxt, int command)
                 if (is_push_button_state_enabled (cctxt->gui_handle->handle))
                         error = device_main (cctxt, command);
                 else
-                        error = LDTP_ERROR_RADIO_BUTTON_STATE_NOT_ENABLED;
+                        error = LDTP_ERROR_PUSH_BUTTON_STATE_NOT_ENABLED;
                 break;
         case LDTP_CMD_MOUSEMOVE:
                 error = device_main (cctxt, command);
@@ -130,9 +130,8 @@ push_button_main (LDTPClientContext* cctxt, int command)
 	case LDTP_CMD_GETOBJECTSIZE:
 		cctxt->resp->data_len = 0;
 		cctxt->resp->data = get_size (cctxt->gui_handle->handle, &error);
-		if (cctxt->resp->data) {
+		if (cctxt->resp->data)
 			cctxt->resp->data_len = g_utf8_strlen (cctxt->resp->data, -1);
-		}
 		break;
 	default:
 		error = LDTP_ERROR_COMMAND_NOT_IMPLEMENTED;
