@@ -44,6 +44,7 @@ static int table = 0,
 	combo_box = 0,
 	page_tab_list = 0,
 	page_tab = 0,
+	link_obj = 0,
 	spin_button = 0,
 	button = 0,
 	tbutton = 0,
@@ -88,6 +89,7 @@ reset_count()
 	combo_box = 0;
 	page_tab_list = 0;
 	page_tab = 0;
+	link_obj = 0;
 	spin_button = 0;
 	button = 0;
 	tbutton = 0;
@@ -596,6 +598,12 @@ get_object_info (Accessible *accessible)
 		obj_info->object_type = g_strdup ("text");
 	}
 #ifdef ENABLE_NEWROLES
+	else if (role == SPI_ROLE_LINK) {
+		obj_info->prefix = g_strdup ("lnk");
+		obj_info->instance_index = link_obj;
+		link_obj++;
+		obj_info->object_type = g_strdup ("link");
+	}
 	else if (role == SPI_ROLE_ENTRY) {
 		obj_info->prefix = g_strdup ("txt");
 		obj_info->instance_index = text;
