@@ -559,8 +559,7 @@ select_row (LDTPClientContext *cctxt, Accessible *object, char *row_text, FILE *
 				log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 				return error;
 			}
-		}
-		else {
+		} else {
 			Accessible_unref (cell);
 			error = LDTP_ERROR_OBJ_NOT_COMPONENT_TYPE;
 			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
@@ -765,7 +764,7 @@ select_last_row (Accessible *object, FILE *log_fp)
 }
 
 static LDTPErrorCode
-does_row_exist (Accessible *object, char *row_text, FILE *log_fp)
+does_row_exist (Accessible *object, gchar *row_text, gboolean partial_match, FILE *log_fp)
 {
 	long n_rows, n_cols;
 	AccessibleTable *table;
@@ -776,7 +775,7 @@ does_row_exist (Accessible *object, char *row_text, FILE *log_fp)
 	table = Accessible_getTable (object);
 	n_rows = AccessibleTable_getNRows (table);
 	n_cols = AccessibleTable_getNColumns (table);
-  
+
 	if (!row_text) {
 		if (n_rows != 0) {
 			log_msg (LDTP_LOG_INFO, "Rows available in Table cell", log_fp);
@@ -789,6 +788,8 @@ does_row_exist (Accessible *object, char *row_text, FILE *log_fp)
 		return error;
 	} else {
 		long i, j;
+		gchar *text = g_strdup_printf("*%s*", row_text);
+		g_print ("does_row_exist: %s %d\n", text, partial_match);
 		for (i = 0; i < n_rows; i++) {
 			for (j = 0; j < n_cols; j++) {
 				long child_count;
@@ -802,13 +803,26 @@ does_row_exist (Accessible *object, char *row_text, FILE *log_fp)
 					for (k = 0; k < child_count; k++) {
 						child = Accessible_getChildAtIndex (cell, k);
 						name = Accessible_getName (child);
-						if (name && g_utf8_collate (name, row_text) == 0) {
+						if (name) {
+							if (ldtp_debug) {
+								g_print ("Name: %s %s\n", name, text);
+								g_print ("Status: %d\n",
+									 g_pattern_match_simple (text,
+												 name));
+							}
+							if ((partial_match &&
+							    g_pattern_match_simple (text,
+										    name)) ||
+							    (!partial_match &&
+							     g_utf8_collate (row_text,
+									     name) == 0)){
+								SPI_freeString (name);
+								Accessible_unref (child);
+								flag = TRUE;
+								break;
+							}
 							SPI_freeString (name);
-							Accessible_unref (child);
-							flag = TRUE;
-							break;
 						} // if
-						SPI_freeString (name);
 						Accessible_unref (child);
 					} // for
 					Accessible_unref (cell);
@@ -816,12 +830,17 @@ does_row_exist (Accessible *object, char *row_text, FILE *log_fp)
 						break;
 				} else {
 					name = Accessible_getName (cell);
-					if (name && g_utf8_collate (name, row_text) == 0) {
-						SPI_freeString (name);
-						flag = TRUE;
-						Accessible_unref (cell);
-						break;
-					} // if
+					if (name)
+						if ((partial_match &&
+						    g_pattern_match_simple (text,
+									    name)) ||
+						    (!partial_match &&
+						     g_utf8_collate (row_text, name) == 0)) {
+							SPI_freeString (name);
+							flag = TRUE;
+							Accessible_unref (cell);
+							break;
+						} // if
 					Accessible_unref (cell);
 				}
 			} // for j
@@ -1124,6 +1143,11 @@ check_row (Accessible *object, int row, int col, FILE *log_fp)
 	char *name = NULL;
 	char msg[256];
 	
+	if (Accessible_isAction (object) == FALSE) {
+		error = LDTP_ERROR_CHECK_ACTION_FAILED;
+		return error;
+	}
+
 	table = Accessible_getTable (object);
 	n_rows = AccessibleTable_getNRows (table);
 	n_cols = AccessibleTable_getNColumns (table);
@@ -1193,6 +1217,11 @@ uncheck_row (Accessible *object, int row, int col, FILE *log_fp)
 	char *name = NULL;
 	char msg[256];
 	
+	if (Accessible_isAction (object) == FALSE) {
+		error = LDTP_ERROR_UNCHECK_ACTION_FAILED;
+		return error;
+	}
+
 	table = Accessible_getTable (object);
 	n_rows = AccessibleTable_getNRows (table);
 	n_cols = AccessibleTable_getNColumns (table);
@@ -1697,11 +1726,23 @@ table_main (LDTPClientContext* cctxt, int command)
 		error = select_row_index (cctxt->gui_handle->handle, row, cctxt->log_fp);
 		break;
 	}
-	case LDTP_CMD_DOESROWEXIST:
+	case LDTP_CMD_DOESROWEXIST: {
+		GSList *l;
+		gchar *data = NULL;
+		long partial_match = 0;
+		l = cctxt->req->arg_list;
+		if (l && l->data) {
+			data = l->data;
+			l = l->next;
+			if (l && l->data)
+				partial_match = atol (l->data);
+		}
 		error = does_row_exist (cctxt->gui_handle->handle,
-					cctxt->req->arg_list->data,
+					data,
+					partial_match,
 					cctxt->log_fp);
 		break;
+	}
 	case LDTP_CMD_GETCELLVALUE:
 		error = get_cell_value (cctxt);
 		/*
