@@ -306,10 +306,14 @@ get_text_value (Accessible *object)
 	accessibleText = Accessible_getText (object);
 	if (accessibleText) {
 		char *tmp = NULL;
-		tmp = AccessibleText_getText (accessibleText, 0, LONG_MAX);
-		g_print ("Text: %s\n", tmp);
-		text = g_strdup (tmp);
-		SPI_freeString (tmp);
+		tmp = AccessibleText_getText (accessibleText, 0,
+					      AccessibleText_getCharacterCount (accessibleText));
+		if (tmp) {
+			if (ldtp_debug)
+				g_print ("Text: %s\n", tmp);
+			text = g_strdup (tmp);
+			SPI_freeString (tmp);
+		}
 		Accessible_unref (accessibleText);
 	}
 	return text;
@@ -706,8 +710,7 @@ compare_text_property (Accessible *object, GSList *l, FILE *log_fp)
 					flag = TRUE;
 					break;
 				}
-			}
-			else {
+			} else {
 				g_free (value);
 				flag = TRUE;
 				break;
