@@ -1069,18 +1069,18 @@ get_row_count (Accessible *object, GSList **l)
 }
 
 static LDTPErrorCode
-does_row_exists (Accessible *object, char *row_text, FILE *log_fp)
+does_row_exist (Accessible *object, gchar *row_text, gboolean partial_match, FILE *log_fp)
 {
 	long n_rows, n_cols;
 	AccessibleTable *table;
-	LDTPErrorCode error;
 	Accessible *cell;
-	gboolean flag = FALSE;
-
+	LDTPErrorCode error;
+	SPIBoolean flag = FALSE;
+  
 	table = Accessible_getTable (object);
 	n_rows = AccessibleTable_getNRows (table);
 	n_cols = AccessibleTable_getNColumns (table);
-  
+
 	if (!row_text) {
 		if (n_rows != 0) {
 			log_msg (LDTP_LOG_INFO, "Rows available in Table cell", log_fp);
@@ -1091,40 +1091,61 @@ does_row_exists (Accessible *object, char *row_text, FILE *log_fp)
 		error = LDTP_ERROR_ROW_DOES_NOT_EXIST;
 		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
 		return error;
-	}
-	else {
+	} else {
 		long i, j;
+		gchar *text = g_strdup_printf("*%s*", row_text);
+		g_print ("does_row_exist: %s %d\n", text, partial_match);
 		for (i = 0; i < n_rows; i++) {
 			for (j = 0; j < n_cols; j++) {
 				long child_count;
-				cell = AccessibleTable_getAccessibleAt (table, i, j);
-				child_count = Accessible_getChildCount (cell);
-				long k;
 				char *name;
 				Accessible *child;
+
+				cell = AccessibleTable_getAccessibleAt (table, i, j);
+				child_count = Accessible_getChildCount (cell);
 				if (child_count > 0) {
+					long k;
 					for (k = 0; k < child_count; k++) {
 						child = Accessible_getChildAtIndex (cell, k);
 						name = Accessible_getName (child);
-						if (name && g_utf8_collate (name, row_text) == 0) {
+						if (name) {
+							if (ldtp_debug) {
+								g_print ("Name: %s %s\n", name, text);
+								g_print ("Status: %d\n",
+									 g_pattern_match_simple (text,
+												 name));
+							}
+							if ((partial_match &&
+							    g_pattern_match_simple (text,
+										    name)) ||
+							    (!partial_match &&
+							     g_utf8_collate (row_text,
+									     name) == 0)){
+								SPI_freeString (name);
+								Accessible_unref (child);
+								flag = TRUE;
+								break;
+							}
 							SPI_freeString (name);
-							Accessible_unref (child);
-							flag = TRUE;
-							break;
 						} // if
-						SPI_freeString (name);
 						Accessible_unref (child);
 					} // for
 					Accessible_unref (cell);
 					if (flag == TRUE)
 						break;
-				}
-				else {
+				} else {
 					name = Accessible_getName (cell);
-					if (name && g_utf8_collate (name, row_text) == 0) {
-						SPI_freeString (name);
-						flag = TRUE;
-					} // if
+					if (name)
+						if ((partial_match &&
+						    g_pattern_match_simple (text,
+									    name)) ||
+						    (!partial_match &&
+						     g_utf8_collate (row_text, name) == 0)) {
+							SPI_freeString (name);
+							flag = TRUE;
+							Accessible_unref (cell);
+							break;
+						} // if
 					Accessible_unref (cell);
 				}
 			} // for j
@@ -1132,13 +1153,13 @@ does_row_exists (Accessible *object, char *row_text, FILE *log_fp)
 				break;
 		} // for i
 		Accessible_unref (table);
-		if (flag == TRUE)
-			return LDTP_ERROR_SUCCESS;
-		else {
-			error = LDTP_ERROR_ROW_DOES_NOT_EXIST;
-			log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
-			return error;
-		}
+	} // else
+	if (flag == TRUE)
+		return LDTP_ERROR_SUCCESS;
+	else {
+		error = LDTP_ERROR_ROW_DOES_NOT_EXIST;
+		log_msg (LDTP_LOG_CAUSE, ldtp_error_get_message (error), log_fp);
+		return error;
 	}
 }
 
@@ -1542,10 +1563,23 @@ tree_table_main (LDTPClientContext* cctxt, int command)
 	case LDTP_CMD_SETCELLVALUE:
 		error = set_cell_value (cctxt);
 		break;
-	case LDTP_CMD_DOESROWEXIST:
-		error = does_row_exists (cctxt->gui_handle->handle,
-					 cctxt->req->arg_list->data, cctxt->log_fp);
+	case LDTP_CMD_DOESROWEXIST: {
+		GSList *l;
+		gchar *data = NULL;
+		long partial_match = 0;
+		l = cctxt->req->arg_list;
+		if (l && l->data) {
+			data = l->data;
+			l = l->next;
+			if (l && l->data)
+				partial_match = atol (l->data);
+		}
+		error = does_row_exist (cctxt->gui_handle->handle,
+					data,
+					partial_match,
+					cctxt->log_fp);
 		break;
+	}
 	case LDTP_CMD_VERIFYPARTIALTABLECELL:
 		error = verify_partial_cell_value (cctxt);
 		break;
@@ -1580,6 +1614,10 @@ tree_table_main (LDTPClientContext* cctxt, int command)
 		long row = 0;
 		long col = 0;
 		GSList *l = cctxt->req->arg_list;
+		if (Accessible_isAction (cctxt->gui_handle->handle) == FALSE) {
+			error = LDTP_ERROR_UNCHECK_ACTION_FAILED;
+			break;
+		}
 		if (l && l->data) {
 			row = atol (l->data);
 			l = l->next;
@@ -1587,6 +1625,7 @@ tree_table_main (LDTPClientContext* cctxt, int command)
 				col = atol (l->data);
 			}
 		}
+		g_print ("Row: %ld Column: %ld\n", row, col);
 		if (get_status (cctxt->gui_handle->handle, row, col) == TRUE)
 			error = do_action (cctxt->gui_handle->handle,
 					   row, col, "toggle", cctxt->log_fp);
